new Vue({
  el: '#stina-campaigns',
  data: {
    i18n: {},
    loading: false,
    campaigns: {
      page: 1,
      limit: 10,
      sort: [],
      filter: [],
      term: '',
      total: 0,
      list: [],
      selected: {
        status: null,
        type: null
      }
    }
  },
  methods: {
    moment(dateTime) {
      return moment(dateTime);
    },
    onSelectFilter(key, value) {
      if (this.campaigns.selected[key] === value|| (value === 'ALL' && this.campaigns.selected[key] === null)) {
        return;
      }

      if (value === 'ALL') {
        this.campaigns.selected[key] = null;
      } else {
        this.campaigns.selected[key] = value;
      }

      this.onRefresh();
    },
    getFilters() {
      const filters = [];

      if (this.campaigns.selected.status !== null) {
        filters.push({
          key: 'campaignStatus',
          value: this.campaigns.selected.status
        });
      }

      if (this.campaigns.selected.type !== null) {
        filters.push({
          key: 'campaignType',
          value: this.campaigns.selected.type
        });
      }

      return filters;
    },
    onChangePage(page) {
      if (page <= 0) {
        return;
      }

      this.campaigns.page = parseInt(page);
      this.onRefresh();
    },
    onRefresh() {
      this.loading = true;

      const that = this;
      const formData = new FormData();

      // Action & Nonce
      formData.append('action', 'crysli_campaigns_load');
      formData.append('security', crysliComponentCampaignsSecurity.loadCampaigns);

      // Other form data
      formData.append('page',   this.campaigns.page);
      formData.append('limit',  this.campaigns.limit);
      formData.append('sort',   JSON.stringify(this.campaigns.sort));
      formData.append('filter', JSON.stringify(this.getFilters()));
      formData.append('term',   this.campaigns.term);

      jQuery.ajax({
        url: ajaxurl,
        type: 'POST',
        cache: false,
        contentType: false,
        processData: false,
        data: formData,
        dataType: 'json',
        timeout: -1,
        success(response) {
          if (!response || response.length === 0) {
            that.campaigns.total = 0;
            that.campaigns.list = [];
          } else {
            that.campaigns.total = response.data.total;
            that.campaigns.list = response.data.list;
          }
        },
        error(error) {
          console.error(error.responseJSON);
          that.campaigns.total = 0;
          that.campaigns.list = [];
        },
        complete() {
          that.loading = false;
        }
      });
    },
    onOpenDuplicateCampaignDialog(campaignUniqueId) {
      const el = document.querySelector('#crysli-campaign-duplicate-campaign-unique-id');

      if (el) {
        el.value = campaignUniqueId;
      }
    },
    getCampaignProviderIcon(provider) {
      return {
        'fas fa-envelope-open-text': provider === 'TRIGGER_DIALOG_LETTER'
      };
    },
    getCampaignStatusClass(campaignStatus) {
      return {
        'info': campaignStatus === 'CAMPAIGN_ACTIVE',
        'dark': campaignStatus === 'CAMPAIGN_INACTIVE',
        'light': campaignStatus === 'CAMPAIGN_DRAFT',
        'success': campaignStatus ==='CAMPAIGN_SUBMITTED',
      }
    },
    toggleDropdown(event) {
      const visibleDropdowns = document.querySelectorAll('.stina-dropdown-menu.show');
      const parent = event.target.parentElement;
      const dropdown = parent.querySelector('.stina-dropdown-menu');

      if (visibleDropdowns) {
        for (let i = 0; i < visibleDropdowns.length; i++) {
          visibleDropdowns[i].classList.remove('show');
        }
      }

      if (dropdown) {
        if (dropdown.classList.contains('show')) {
          dropdown.classList.remove('show');
        } else {
          dropdown.classList.add('show');
        }
      }
    }
  },
  mounted() {
    this.i18n = i18n;
    this.onRefresh();
  }
});