new Vue({
  el: '#stina-settings',
  data: {
    loading: false,
    settings: {
      general: {},
      services: {
        deutschePostTriggerDialog: {}
      },
      tools: {
        logging: {}
      },
      system: {
        general: {
          environment: '',
          applicationMode: 'LIVE',
          logLevel: 400,
        },
      },
      support: {}
    },
    section: {
      tools: {
        loaded: true,
        data: {},
        additionalData: {
          logFileContent: null
        }
      }
    },
    active: {
      section: null
    },
    profile: null
  },
  methods: {
    moment(dateTime) {
      return moment(dateTime);
    },
    onSelectSection(section) {
      // Do nothing if the same button was clicked
      if (this.active.section === section) {
        return;
      }

      const that = this;

      switch (section) {
        case 'general':
        case 'services':
          if (this.profile !== null) {
            this.active.section = section
            break;
          }

          this.loadUserProfile()
            .then(function (userProfile) {
              that.profile = userProfile;
              that.active.section = section;
            })
            .catch(function (error) {
              console.error(error);
              that.profile = null;
              that.active.section = section;
            });
          break;
        default:
          this.active.section = section;
          break;
      }
    },
    loadUserProfile() {
      this.loading = true;

      const that = this;
      const formData = new FormData();

      // Action & Nonce
      formData.append('action', 'crysli_settings_load_user_profile');
      formData.append('security', security.loadUserProfile);

      return new Promise(function(resolve, reject) {
        jQuery.ajax({
          url: ajaxurl,
          type: 'POST',
          cache: false,
          contentType: false,
          processData: false,
          data: formData,
          dataType: 'json',
          timeout: -1,
          success(response) {
            resolve(response);
          },
          error(error) {
            reject(error);
          },
          complete() {
            that.loading = false;
          }
        });
      });
    },
    loadSectionServices() {
      this.loading = true;

      const formData = new FormData();
      const that = this;

      // Action & Nonce
      formData.append('action', 'crysli_settings_load_section_services');
      formData.append('security', security.loadSectionServices);

      return new Promise(function(resolve, reject) {
        jQuery.ajax({
          url: ajaxurl,
          type: 'POST',
          cache: false,
          contentType: false,
          processData: false,
          data: formData,
          dataType: 'json',
          timeout: -1,
          success(response) {
            resolve(response);
          },
          error(error) {
            reject(error);
          },
          complete() {
            that.loading = false;
          }
        });
      });
    },
    onSubmit() {
      this.loading = true;

      const formData = new FormData();
      const that = this;

      // Action & Nonce
      formData.append('action', 'crysli_settings_save');
      formData.append('security', security.save);

      // System
      formData.append('system_general_environment', this.settings.system.general.environment);
      formData.append('system_general_applicationMode', this.settings.system.general.applicationMode);
      formData.append('system_general_logLevel', this.settings.system.general.logLevel);

      jQuery.ajax({
        url: ajaxurl,
        type: 'POST',
        cache: false,
        contentType: false,
        processData: false,
        data: formData,
        dataType: 'json',
        timeout: -1,
        success() {
          console.info('STINA Crystal LIFT - Settings saved.');
        },
        error(error) {
          console.error(error.responseJSON);
        },
        complete() {
          that.loading = false;
        }
      });
    },
    onSelectLogFile(event) {
      this.loading = true;

      const formData = new FormData();
      const that = this;

      // Action & Nonce
      formData.append('action', 'crysli_settings_load_log_file');
      formData.append('security', security.loadLogFile);
      formData.append('file', event.target.value);

      jQuery.ajax({
        url: ajaxurl,
        type: 'POST',
        cache: false,
        contentType: false,
        processData: false,
        data: formData,
        dataType: 'json',
        timeout: -1,
        success(response) {
          that.section.tools.additionalData.logFileContent = response;
        },
        error(error) {
          console.log(error);
        },
        complete() {
          that.loading = false;
        }
      });
    }
  },
  mounted() {
    this.loading = true;

    const formData = new FormData();
    const that = this;

    // Action & Nonce
    formData.append('action', 'crysli_settings_load');
    formData.append('security', security.load);

    jQuery.ajax({
      url: ajaxurl,
      type: 'POST',
      cache: false,
      contentType: false,
      processData: false,
      data: formData,
      dataType: 'json',
      timeout: -1,
      success(response) {
        that.settings = response;
        that.onSelectSection('general');
      },
      error(error) {
        console.error(error.responseJSON);
      },
      complete() {
        that.loading = false;
      }
    });
  }
});