var crysliModalCampaignConfigureEventWizard = new Vue({
  el: '#crysli-modal-campaign-configure-event-wizard',
  data: {
    i18n: {},
    loading: false,
    steps: {
      current: 1,
      max: 1
    },
    selected: {},
    active: {
      object: '',
      trigger: '',
      conditions: [],
    },
    events: [],
    conditions: [],
    campaign: {
      data: {}
    }
  },
  methods: {
    close() {
      this.$el.classList.remove('open');
    },
    nextStep() {
      if (this.inputValidation()) {
        ++this.steps.current
      }
    },
    previousStep() {
      --this.steps.current;
    },
    getStepClass(step) {
      return {
        active: step === this.steps.current,
        pending: step > this.steps.current,
        complete: step < this.steps.current
      };
    },
    inputValidation() {
      return true;
    },
    onSelectObject() {
      const that = this;
      this.conditions = [];

      this.getObjectEvents(this.active.object)
        .then(function(result) {
          that.events = result.events;
        })
        .catch(function (error) {
          console.error(error);
        });
    },
    onSelectEvent() {
      const that = this;

      this.getEventConditions(this.active.object, this.active.trigger)
        .then(function(result) {
          that.conditions = result.conditions;
        })
        .catch(function (error) {
          console.error(error);
        });
    },
    getObjectEvents(object) {
      const formData = new FormData();

      formData.append('action', 'crysli_get_object_events');
      formData.append('security', security.getObjectEvents);
      formData.append('object', object);

      return new Promise(function (resolve, reject) {
        jQuery.ajax({
          url: ajaxurl,
          type: 'POST',
          cache: false,
          contentType: false,
          processData: false,
          data: formData,
          dataType: 'json',
          timeout: -1,
          success(response) {
            resolve(response);
          },
          error(error) {
            console.error(error.responseJSON);
            reject(error);
          }
        });
      });
    },
    getEventConditions(object, event) {
      const formData = new FormData();

      formData.append('action', 'crysli_get_event_conditions');
      formData.append('security', security.getEventConditions);
      formData.append('object', object);
      formData.append('event', event);

      return new Promise(function (resolve, reject) {
        jQuery.ajax({
          url: ajaxurl,
          type: 'POST',
          cache: false,
          contentType: false,
          processData: false,
          data: formData,
          dataType: 'json',
          timeout: -1,
          success(response) {
            resolve(response);
          },
          error(error) {
            console.error(error.responseJSON);
            reject(error);
          }
        });
      });
    },
    getConditionOperators(entity) {
      let operators = [];
      const filteredConditions = this.conditions.filter(condition => {
        return condition.entity.value === entity;
      });

      if (filteredConditions.length === 1) {
        operators = filteredConditions[0].operators;
      }

      return operators;
    },
    getConditionAjaxProp(entity) {
      return {
        cache: false,
        delay: 500,
        url: ajaxurl,
        method: 'POST',
        dataType: 'json',
        data(params) {
          return {
            action: 'crysli_condition_dropdown_search',
            security: security.dropdownSearch,
            term: params.term,
            page: params.page,
            hook: 'crysli_filter_values_' + entity
          };
        },
        processResults(data, params) {
          params.page = params.page || 1;

          return {
            results: data.results,
            pagination: {
              more: data.pagination.more
            }
          };
        }
      };
    },
    getConditionDropdownProp(entity) {
      let prop = i18n.searchFor;

      if (!entity) {
        return prop;
      }

      prop += ' ' + i18n.entity[entity];

      return prop;
    },
    onUpdateConditionValue(value, index) {
      this.active.conditions[index].value = value;
    }
  },
  mounted() {
    const that = this;

    window.addEventListener('keydown', function(event) {
      if (event.key === 'Escape' && that.$el.classList.contains('open')) {
        that.close();
      }
    });
  },
  beforeMount() {
    const that = this;

    that.i18n = i18n;
    that.campaign.data = data.campaign;

    const formData = new FormData();
    let eventUniqueId = null;

    if (data.campaign.events.length > 0) {
      eventUniqueId = data.campaign.events[0].eventUniqueId
    }

    formData.append('action', 'crysli_modal_campaign_configure_event_wizard_load');
    formData.append('security', security.modalCampaignConfigureEventWizardLoad);
    formData.append('campaign_unique_id', data.campaign.campaignUniqueId);
    formData.append('campaign_event_unique_id', eventUniqueId);

    jQuery.ajax({
      url: ajaxurl,
      type: 'POST',
      cache: false,
      contentType: false,
      processData: false,
      data: formData,
      dataType: 'json',
      timeout: -1,
      success(response) {
        if (response.config) {
          that.active.object     = response.config.object;
          that.active.trigger    = response.config.trigger;
          that.active.conditions = response.config.conditions;

          if (that.active.conditions && that.active.conditions.length === 0) {
            that.active.conditions.push({
              entity: '',
              operator: '',
              value: []
            });
          }

          that.getObjectEvents(response.config.object)
            .then(function(getObjectEventsResponse) {
              that.events = getObjectEventsResponse.events;

              that.getEventConditions(response.config.object, response.config.trigger)
                .then(function(getEventConditionsResponse) {
                  that.conditions = getEventConditionsResponse.conditions;
                })
                .catch(function (error) {
                  console.error(error);
                });
            })
            .catch(function (error) {
              console.error(error);
            });
        }
      },
      error(error) {
        console.error(error.responseJSON);
      },
      complete() {
      }
    });
  }
});