var crysliModalCampaignEditContentWizard = new Vue({
  el: '#crysli-modal-campaign-edit-content-wizard',
  data: {
    i18n: {},
    loading: false,
    steps: {
      current: 1,
      max: 1
    },
    selected: {
      campaignType: 'CAMPAIGN_TYPE_DP_TRIGGER_DIALOG_NEW'
    },
    providers: {
      DP_TRIGGER_DIALOG: {
        new: false,
        campaignName: '',
        variables: {
          mandatory: [],
          existing: [],
          new: []
        }
      }
    },
    campaign: {}
  },
  methods: {
    close() {
      this.$el.classList.remove('open');
    },
    nextStep() {
      ++this.steps.current
    },
    previousStep() {
      --this.steps.current;
    },
    getStepClass(step) {
      return {
        active: step === this.steps.current,
        pending: step > this.steps.current,
        complete: step < this.steps.current
      };
    },
    onSelectCampaignType(type) {
      this.selected.campaignType = type;
      this.nextStep();
    },
    onAddVariable() {
      const variables = this.providers.DP_TRIGGER_DIALOG.variables.new;
      let highestIndex = 0;

      if (variables.length > 0) {
        highestIndex = variables.reduce((max, p) => p.id > max ? p.id : max, variables[0].id)
      }

      this.providers.DP_TRIGGER_DIALOG.variables.new.push({
        id: ++highestIndex,
        name: '',
        type: 'string',
        mappedTo: ''
      });
    },
    onRemoveVariable(variableId, key) {
      let loc = undefined;

      this.providers.DP_TRIGGER_DIALOG.variables[key].find(function (variable, index) {
        loc = index;
        return variable.id === variableId;
      });

      this.providers.DP_TRIGGER_DIALOG.variables[key].splice(loc, 1);
    },
    findObjectByKey(array, key, value) {
      for (let i = 0; i < array.length; i++) {
        if (array[i][key] === value) {
          return array[i];
        }
      }

      return null;
    },
    getExistingVariableCount(i) {
      return i + this.providers.DP_TRIGGER_DIALOG.variables.mandatory.length;
    },
    getNewVariableCount(i) {
      return i
        + this.providers.DP_TRIGGER_DIALOG.variables.mandatory.length
        + this.providers.DP_TRIGGER_DIALOG.variables.existing.length;
    }
  },
  mounted() {
    const that = this;

    window.addEventListener('keydown', function(event) {
      if (event.key === 'Escape' && that.$el.classList.contains('open')) {
        that.close();
      }
    });
  },
  beforeMount() {
    this.campaign = data.campaign;
    this.i18n = i18n;
    const config = data.campaign.actions[0].config;
    const mandatoryVariables = [
      {
        id: 0,
        name: this.i18n.variableMappingFields.FIRST_NAME,
        type: 'string',
        field: 'FIRST_NAME',
        mappedTo: 'WC_SHIPPING_ADDRESS_FIRST_NAME'
      },
      {
        id: 1,
        name: this.i18n.variableMappingFields.LAST_NAME,
        type: 'string',
        field: 'LAST_NAME',
        mappedTo: 'WC_SHIPPING_ADDRESS_LAST_NAME'
      },
      {
        id: 2,
        name: this.i18n.variableMappingFields.COMPANY,
        type: 'string',
        field: 'COMPANY',
        mappedTo: 'WC_SHIPPING_ADDRESS_COMPANY'
      },
      {
        id: 3,
        name: this.i18n.variableMappingFields.STREET,
        type: 'string',
        field: 'STREET',
        mappedTo: 'WC_SHIPPING_ADDRESS_ADDRESS_LINE_1'
      },
      {
        id: 4,
        name: this.i18n.variableMappingFields.ZIP_CODE,
        type: 'zip',
        field: 'ZIP_CODE',
        mappedTo: 'WC_SHIPPING_ADDRESS_POSTCODE'
      },
      {
        id: 5,
        name: this.i18n.variableMappingFields.CITY,
        type: 'string',
        field: 'CITY',
        mappedTo: 'WC_SHIPPING_ADDRESS_CITY'
      },
      {
        id: 6,
        name: this.i18n.variableMappingFields.COUNTRY,
        type: 'countryCode',
        field: 'COUNTRY',
        mappedTo: 'WC_SHIPPING_ADDRESS_COUNTRY'
      }
    ];

    // New Campaign
    if (config === null) {
      this.providers.DP_TRIGGER_DIALOG.variables.mandatory = mandatoryVariables;
      this.providers.DP_TRIGGER_DIALOG.new = true;
      return;
    }

    let variables = [];

    for (let i = 0; i < config.variables.length; i++) {
      const currentVariable = config.variables[i];
      let mappedTo = '';
      let field = null;
      let mappedVariable = null;

      if (data.campaignVariableMapping !== null) {
        mappedVariable = this.findObjectByKey(
          data.campaignVariableMapping,
          'name',
          currentVariable.name
        );

        if (mappedVariable) {
          mappedTo = mappedVariable.mapped_to;
          field = mappedVariable.field;
        }
      }

      let variableToPush = {
        id: i,
        name: currentVariable.name,
        type: currentVariable.type,
        mappedTo: mappedTo,
        field: field,
      };

      if (mappedVariable && mappedTo === 'TEXT_FIELD') {
        variableToPush.value = mappedVariable.value;
      }

      variables.push(variableToPush);
    }

    // Split the mandatory elements
    const mandatoryCount = mandatoryVariables.length;
    const mandatory = variables.splice(0, mandatoryCount);

    this.providers.DP_TRIGGER_DIALOG.campaignName = config.campaignData.campaignName;
    this.providers.DP_TRIGGER_DIALOG.startDate = config.campaignData.startDate;
    this.providers.DP_TRIGGER_DIALOG.endDate = config.campaignData.endDate;

    this.providers.DP_TRIGGER_DIALOG.variables.mandatory = mandatory;
    this.providers.DP_TRIGGER_DIALOG.variables.existing = variables;
    this.providers.DP_TRIGGER_DIALOG.variables.new = [];
  }
});