new Vue({
  el: '#crysli-modal-campaign-edit-recipients-wizard',
  data: {
    loading: false,
    steps: {
      current: 1,
      max: 1
    },
    selectAll: false,
    selected: [],
    conditions: [],
    filters: {},
    users: {
      total: 0,
      list: [],
      term: '',
      limit: -1,
      page: 1,
      orderBy: 'ID',
      order: 'DESC',
      lastPage: null
    }
  },
  methods: {
    close() {
      this.$el.classList.remove('open');
    },
    nextStep() {
      ++this.steps.current
    },
    previousStep() {
      --this.steps.current;
    },
    getStepClass(step) {
      return {
        active: step === this.steps.current,
        pending: step > this.steps.current,
        complete: step < this.steps.current
      };
    },
    getObjectEntities(object) {
      let values = [];

      const entities = this.filters.filter(filter => {
        return filter.name === object;
      });

      if (entities.length === 1) {
        values = entities[0].values;
      }

      return values;
    },
    getObjectEntityFields(object, entity) {
      let values = this.getObjectEntities(object);

      const foundEntity = values.filter(currentEntity => {
        return currentEntity.name === entity;
      });

      if (foundEntity.length !== 1) {
        return [];
      }

      return foundEntity[0].fields;
    },
    getInputFieldType(object, entity) {
      const fields = this.getObjectEntityFields(object, entity);

      if (fields.length !== 1) {
        return 'text';
      }

      switch (fields[0].type) {
        case 'NUMBER':
          return 'number';
        case 'DATE':
          return 'DATE';
        case 'MULTI':
        default:
          return 'text';
      }
    },
    getConditionAjaxProp(entity) {
      return {
        cache: false,
        delay: 500,
        url: ajaxurl,
        method: 'POST',
        dataType: 'json',
        data(params) {
          return {
            action: 'crysli_condition_dropdown_search',
            security: security.dropdownSearch,
            term: params.term,
            page: params.page,
            hook: 'crysli_filter_values_' + entity
          };
        },
        processResults(data, params) {
          params.page = params.page || 1;

          return {
            results: data.results,
            pagination: {
              more: data.pagination.more
            }
          };
        }
      };
    },
    getConditionDropdownProp(entity) {
      let prop = i18n.searchFor;

      if (!entity) {
        return prop;
      }

      prop += ' ' + i18n.entity[entity];

      return prop;
    },
    isMultiField(entity) {
      switch (entity) {
        case 'language':
        case 'shipping_country':
        case 'billing_country':
          return true;
        default:
          return false;
      }
    },
    onChangePage(page) {
      if (page <= 0) {
        return;
      }

      this.users.page = parseInt(page);
      this.onRefresh();
    },
    onSelectAll() {
      this.users.list.forEach(user => {
        const index = this.selected.indexOf(user.id);

        if (index === -1) {
          if (this.selectAll) {
            this.selected.push(user.id);
          }
        } else {
          if (!this.selectAll) {
            this.selected.splice(index, 1);
          }
        }
      });
    },
    onRefresh() {
      this.loading = true;

      let formData = new FormData();
      const that = this;

      formData.append('action', 'crysli_modal_campaign_edit_recipients_wizard_load');
      formData.append('security', security.loadSubscribers);
      formData.append('term', this.users.term);
      formData.append('limit', this.users.limit);
      formData.append('page', this.users.page);
      formData.append('orderBy', this.users.orderBy);
      formData.append('order', this.users.order);
      formData.append('conditions', JSON.stringify(this.conditions));

      return new Promise((resolve, reject) => {
        jQuery.ajax({
          url: ajaxurl,
          type: 'POST',
          cache: false,
          contentType: false,
          processData: false,
          data: formData,
          dataType: 'json',
          timeout: -1,
          success(response) {
            that.users.total = response.total;
            that.users.list = response.list;
            that.users.lastPage = Math.ceil(response.total / that.users.limit);
            resolve(response);
          },
          error(error) {
            console.error(error.responseJSON);
            that.users.total = 0;
            that.users.list = [];
            that.users.lastPage = 1;
            reject(error);
          },
          complete() {
            that.loading = false;
          }
        });
      });
    },
    onFilterRecipients() {
      this.onRefresh()
        .then(() => {
          this.selected = [];

          this.users.list.forEach(user => {
            this.selected.push(user.id);
          });
        });
    },
    onAddCondition() {
      this.conditions.push({
        object: '',
        entity: '',
        operator: '',
        value: null
      });
    },
    onRemoveCondition(index) {
      this.conditions.splice(index, 1);
    },
    onValidateConditions() {
      if (this.conditions.length === 0) {
        return true;
      }

      for (let i = 0; i < this.conditions.length; i++) {
        let condition = this.conditions[i];

        if (!condition.object || !condition.entity || !condition.operator || !condition.value) {
          return false;
        }
      }

      return true;
    },
    onUpdateConditionValue(value, index) {
      this.conditions[index].value = value;
    }
  },
  mounted() {
    const that = this;

    window.addEventListener('keydown', function(event) {
      if (event.key === 'Escape' && that.$el.classList.contains('open')) {
        that.close();
      }
    });

    if (this.conditions) {
      const el = document.querySelector('#stina-condition-value-0');

      this.conditions.forEach(condition => {
        if (Array.isArray(condition.value)) {
          condition.value.forEach(value => {
            let option = document.createElement('option');
            option.value = value;
            option.setAttribute('selected', 'selected');
            option.innerHTML = value;

            if (condition.entity === 'shipping_country' || condition.entity === 'billing_country') {
              option.innerHTML = data.countries[value];
            }

            if (condition.entity === 'language') {
              option.innerHTML = data.languages[value];
            }

            el.appendChild(option);
          });
        }
      });
    }
  },
  beforeMount() {
    const conditions = data.conditions;

    if (conditions && conditions.length > 0) {
      this.conditions = conditions;
    }

    this.filters = data.filters;
    this.selected = data.campaignRecipients;
    this.onRefresh();
  }
});