<?php


namespace STINA\CrystalLift\Abstracts;

use Exception;
use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Exception\ServerException;
use STINA\CrystalLift\Logger;
use STINA\Library\Abstracts\Singleton;
use STINA\Library\Interfaces\Connector as ConnectorInterface;
use Throwable;
use function GuzzleHttp\json_decode as guzzle_http_json_decode;

defined('ABSPATH') || exit;

abstract class Service extends Singleton
{
    /**
     * @var ConnectorInterface
     */
    protected $connector;

    /**
     * @var Logger
     */
    protected $logger;

    /**
     * @param array        $infoObject  The request info object (body)
     * @param false|string $auth        The request authentication type
     * @param false|string $bearerToken The request bearer token
     * @param string       $method      The request method
     * @return false|array
     * @throws GuzzleException
     */
    public function request($infoObject, $auth = false, $bearerToken = false, $method = 'POST')
    {
        try {
            $response = $this->connector->request($infoObject, $auth, $bearerToken, $method);
            return guzzle_http_json_decode($response->getBody(), true);
        } catch (ClientException $ce) {
            $this->logException($infoObject, $ce);
        } catch (ServerException $se) {
            $this->logException($infoObject, $se);
        } catch (Exception $e) {
            $this->logException($infoObject, $e);
        }

        return false;
    }

    /**
     * @param array     $infoObject
     * @param Throwable $e
     * @return void
     */
    protected function logException(array $infoObject, $e)
    {
        if ($this->logger !== null) {
            if ($e instanceof ClientException || $e instanceof ServerException) {
                $message = $infoObject['payload']['type'] . ' ' . $e->getMessage();
                $trace   = array(
                    'REQUEST'  => guzzle_http_json_decode($e->getRequest()->getBody(), true),
                    'RESPONSE' => guzzle_http_json_decode($e->getResponse()->getBody(), true)
                );
            } else {
                $message = $infoObject['payload']['type'] . ' ' . $e->getMessage();
                $trace   = $e->getTrace();
            }

            $this->logger->error($message, $trace);
        }
    }
}