<?php


namespace STINA\CrystalLift\Controllers;

defined('ABSPATH') || exit;

class Campaign
{
    /**
     * Campaign constructor.
     */
    public function __construct()
    {
        add_action('wp_ajax_crysli_get_object_events',         array($this, 'getObjectEvents'),         10, 1);
        add_action('wp_ajax_crysli_get_event_conditions',      array($this, 'getEventConditions'),      10, 1);
        add_action('wp_ajax_crysli_condition_dropdown_search', array($this, 'conditionDropdownSearch'), 10, 1);
    }

    /**
     * Retrieves possible events for the given object.
     */
    public function getObjectEvents()
    {
        check_ajax_referer('crysli_modal_campaign_edit_get_object_events', 'security');

        $object = sanitize_text_field($_POST['object']);

        if (!in_array($object, array('', 'customer', 'order'))) {
            wp_send_json('Object must be a blank string or one of: [customer, order]', 403);
        }

        $payload = array(
            'events' => crysli_get_object_events($object)
        );

        wp_send_json($payload, 200);
    }

    /**
     * Retrieves possible conditions for the given object.
     */
    public function getEventConditions()
    {
        check_ajax_referer('crysli_modal_campaign_edit_get_event_conditions', 'security');

        $object = sanitize_text_field($_POST['object']);
        $event = sanitize_text_field($_POST['event']);

        $payload = array(
            'conditions' => crysli_get_event_conditions($object, $event)
        );

        wp_send_json($payload, 200);
    }

    /**
     * Performs the dropdown search for the conditions.
     */
    public function conditionDropdownSearch()
    {
        check_ajax_referer('crysli_modal_campaign_edit_dropdown_search', 'security');

        $hook   = sanitize_text_field($_POST['hook']);
        $term   = isset($_POST['term']) ? (string)wp_unslash($_POST['term']) : '';
        $page   = isset($_POST['page']) ? intval($_POST['page'])             : 1;
        $limit  = 10;
        $offset = ($page - 1) * 10;

        wp_send_json(apply_filters($hook, $page, $limit, $term, $offset), 200);
    }
}