<?php

namespace STINA\CrystalLift\Controllers;

use WC_Countries;
use WC_Product;

defined('ABSPATH') || exit;

class FilterValues
{
    /**
     * FilterValues constructor.
     */
    public function __construct()
    {
        add_filter('crysli_filter_values_product',          array($this, 'product'),  10, 4);
        add_filter('crysli_filter_values_billing_country',  array($this, 'country'),  10, 4);
        add_filter('crysli_filter_values_shipping_country', array($this, 'country'),  10, 4);
        add_filter('crysli_filter_values_language',         array($this, 'language'), 10, 4);
    }

    /**
     * @param int    $page
     * @param int    $limit
     * @param string $term
     * @param int    $offset
     * @return array
     */
    public function product($page, $limit, $term, $offset)
    {
        $results = array();
        $more    = true;

        global $wpdb;

        $sql ="
            SELECT
                DISTINCT (posts.ID)
            FROM
                $wpdb->posts as posts
            INNER JOIN
                $wpdb->postmeta as meta
                    ON 1=1
                    AND posts.ID = meta.post_id
            WHERE
                1=1
                AND posts.post_title LIKE '%$term%'
                AND (posts.post_type = 'product' OR posts.post_type = 'product_variation')
            ORDER BY posts.ID DESC
            LIMIT $limit
            OFFSET $offset
        ";

        $products = $wpdb->get_col($sql);

        if (count($products) < $limit) {
            $more = false;
        }

        foreach ($products as $productId) {
            /** @var WC_Product $product */
            $product = wc_get_product($productId);

            if (!$product) {
                continue;
            }

            $text = sprintf(
            /* translators: $1: product id, $2 product name */
                '(#%1$s) %2$s',
                $product->get_id(),
                $product->get_name()
            );

            $results[] = array(
                'id' => $product->get_id(),
                'text' => $text
            );
        }

        return $this->payload($page, $results, $more);
    }

    /**
     * @param int    $page
     * @param int    $limit
     * @param string $term
     * @param int    $offset
     * @return array
     */
    public function country($page, $limit, $term, $offset)
    {
        $results = array();
        $more = true;

        /** @var WC_Countries $wooCountries */
        $wooCountries = WC()->countries;

        if ($term) {
            $countries = array_filter(
                $wooCountries->get_countries(),
                function($country) use ($term) {
                    $term    = strtolower($term);
                    $country = strtolower($country);

                    return strpos($country, $term) !== false;
                },
                ARRAY_FILTER_USE_BOTH
            );
        } else {
            $countries = $wooCountries->get_countries();
        }

        $paginated = array_slice($countries, $offset, $limit);

        if (count($paginated) < $limit) {
            $more = false;
        }

        foreach ($paginated as $iso2 => $country) {
            $results[] = array(
                'id'   => $iso2,
                'text' => $country
            );
        }

        return $this->payload($page, $results, $more);
    }

    /**
     * @param int    $page
     * @param int    $limit
     * @param string $term
     * @param int    $offset
     * @return array
     */
    public function language($page, $limit, $term, $offset)
    {
        $results = array();

        if (!function_exists('wp_get_available_translations')) {
            require_once ABSPATH . 'wp-admin/includes/translation-install.php';
        }

        $languages = get_available_languages();
        $translations = wp_get_available_translations();

        foreach ($languages as $language) {
            if (isset($translations[$language])) {
                $englishName = $translations[$language]['english_name'];

                if ($term) {
                    if (strpos(strtolower($englishName), strtolower($term)) !== false) {
                        $results[] = array(
                            'id' => $language,
                            'text' => $englishName
                        );
                    }
                } else {
                    $results[] = array(
                        'id' => $language,
                        'text' => $englishName
                    );
                }

            }
        }

        return $this->payload($page, $results, false);
    }

    /**
     * Returns a select2 compatible ajax response object.
     *
     * @param int   $page
     * @param array $results
     * @param bool  $more
     * @return array
     */
    private function payload($page, $results, $more)
    {
        return array(
            'page'    => $page,
            'results' => $results,
            'pagination' => array(
                'more' => $more
            )
        );
    }
}