<?php


namespace STINA\CrystalLift;

use Exception;
use STINA\Library\Abstracts\Singleton;
use STINA\Library\Package as SharedLibraryPackage;

defined('ABSPATH') || exit;

class Plugin extends Singleton
{
    /**
     * @var Logger
     */
    protected static $logger;

    /**
     * Plugin constructor.
     */
    public function __construct()
    {
        $this->defineConstants();

        $lib = SharedLibraryPackage::instance();

        // Only bootstrap the components if they haven't already been bootstrapped by another plugin.
        if ($lib->isLoaded() === false) {
            $lib->bootstrap(CRYSLI_PLUGIN_DIR, CRYSLI_PLUGIN_URL);
        }

        register_activation_hook(CRYSLI_PLUGIN_FILE,   array('\STINA\CrystalLift\Setup', 'activate'));
        register_deactivation_hook(CRYSLI_PLUGIN_FILE, array('\STINA\CrystalLift\Setup', 'deactivate'));
        register_uninstall_hook(CRYSLI_PLUGIN_FILE,    array('\STINA\CrystalLift\Setup', 'uninstall'));

        add_action('init',                  array($this, 'init'));
        add_action('admin_enqueue_scripts', array($this, 'adminEnqueueScripts'));
    }

    /**
     * Initializes the plugin when WordPress loads
     */
    public function init()
    {
        load_plugin_textdomain(
            'stina-crystal-lift',
            false,
            basename(dirname(__DIR__)) . '/languages'
        );

        // Load the plugin controllers
        new Controllers\Campaign();
        new Controllers\Event();
        new Controllers\FilterValues();

        // Load the plugin components
        new Components\Dashboard();
        new Components\Campaigns();
        new Components\Settings();
    }

    /**
     * Defines all plugin constants.
     */
    private function defineConstants()
    {
        if (!defined('CRYSLI_ABSPATH_LENGTH')) {
            define('CRYSLI_ABSPATH_LENGTH', strlen(ABSPATH));
        }

        define('CRYSLI_ABSPATH', dirname(CRYSLI_PLUGIN_FILE) . '/');
        define('CRYSLI_PLUGIN_BASENAME', plugin_basename(CRYSLI_PLUGIN_FILE));

        // Directories
        define('CRYSLI_ASSETS_DIR', CRYSLI_ABSPATH . 'assets/');
        define('CRYSLI_LOG_DIR', CRYSLI_ABSPATH . 'logs/');
        define('CRYSLI_TEMPLATES_DIR', CRYSLI_ABSPATH . 'templates/');
        define('CRYSLI_MIGRATIONS_DIR', CRYSLI_ABSPATH . 'migrations/');
        define('CRYSLI_CSS_DIR', CRYSLI_ASSETS_DIR . 'css/');

        // URL's
        define('CRYSLI_ASSETS_URL', CRYSLI_PLUGIN_URL . 'assets/');
        define('CRYSLI_ETC_URL', CRYSLI_ASSETS_URL . 'etc/');
        define('CRYSLI_CSS_URL', CRYSLI_ASSETS_URL . 'css/');
        define('CRYSLI_JS_URL', CRYSLI_ASSETS_URL . 'js/');
        define('CRYSLI_IMG_URL', CRYSLI_ASSETS_URL . 'img/');

        // Application specific
        define('CRYSLI_NODE_PORTFOLIO_ELEMENT_UNIQUE_ID', '04d5b79b-0a66-4b69-991d-254f91e409a5');
    }

    /**
     * Register and enqueue plugin-specific assets.
     *
     * @param string $hook The current page hook
     * @throws Exception
     */
    public function adminEnqueueScripts($hook)
    {
        $assetsManager = new Assets();

        $assetsManager->registerJavaScript();
        $assetsManager->registerStyleSheets();
    }

    /**
     * Retrieves the plugin logger instance.
     *
     * @param string $file The .log file which will be used.
     *
     * @return Logger
     */
    public function logger($file = Logger::LOG_PLUGIN)
    {
        if (self::$logger === null) {
            self::$logger = new Logger();
        }

        self::$logger->setLogger($file);

        return self::$logger;
    }
}