<?php


namespace STINA\CrystalLift\Services;

use Exception;
use GuzzleHttp\Exception\ClientException;
use stdClass;
use STINA\CrystalLift\Abstracts\Service as AbstractService;
use STINA\CrystalLift\Logger;
use STINA\Library\Connector;
use function GuzzleHttp\json_decode;

defined('ABSPATH') || exit;

class Router extends AbstractService
{
    /**
     * Node constructor.
     */
    public function __construct()
    {
        $this->connector = new Connector('https://r00002.stina-global.com', 'p00030', 'v1');
    }

    /**
     * Retrieves the node configuration from the remote service.
     *
     * @throws Exception
     * @return bool|stdClass
     */
    public function openNodeGetEnvironments()
    {
        $infoObject = $this->connector->createInfoObject(
            'OPEN_NODE_GET_ENVIRONMENTS',
            null,
            '',
            array(
                'servicePortfolioElementUniqueId' => '105463d8-af7e-47c8-a9b4-f4fab75de6a3',
                'hostRegion' => 'FR',
                'userRegion' => 'AT',
                'clientRegion' => 'DE'
            )
        );

        try {
            $response = $this->connector->request($infoObject);
        } catch (ClientException $e) {
            $logger = Logger::instance();
            $logger->setLogger(Logger::LOG_API);
            $logger->error($e->getResponse()->getBody()->getContents(), $e->getTrace());
            return false;
        }

        return json_decode($response->getBody()->getContents());
    }
}