<?php


namespace STINA\CrystalLift;

use Exception;
use STINA\CrystalLift\Services\CrystalLift as CrystalLiftService;
use STINA\CrystalLift\Services\Router as RouterService;
use wpdb;

defined('ABSPATH') || exit;

class Setup
{
    /**
     * @var string
     */
    const CAMPAIGN_META_TABLE_NAME = 'stina_crysli_campaign_meta';

    /**
     * @var string
     */
    const CAMPAIGN_TRIGGER_TABLE_NAME = 'stina_crysli_campaign_trigger';

    /**
     * @var string
     */
    const CAMPAIGN_RECIPIENT_REL_TABLE_NAME = 'stina_crysli_campaign_recipient_rel';

    /**
     * @var array
     */
    protected $tables;

    /**
     * Activate plugin script
     *
     * @throws Exception
     */
    public static function activate()
    {
        self::initializeNode();
        self::createTables();
    }

    /**
     * Deactivate plugin script
     */
    public static function deactivate()
    {
        // TODO
    }

    /**
     * Uninstall plugin script
     */
    public static function uninstall()
    {
        // TODO
    }

    public static function initializeNode()
    {
        // Retrieves the remote service configuration
        $getConfigurationResponse = RouterService::instance()->openNodeGetEnvironments();

        if ($getConfigurationResponse === false) {
            throw new Exception('Could not connect to the remote service to retrieve the node configuration.');
        }

        $availableEnvs = array();
        $environments  = json_decode(json_encode($getConfigurationResponse->data->environments), true);
        $baseUri       = false;

        foreach ($environments as $environment) {
            if ($environment['default'] === true) {
                $availableEnvs = array($environment);
                $baseUri = $environment['url'];
                break;
            }
        }

        update_option('crysli_environments', $availableEnvs);
        update_option('crysli_environment', $baseUri);

        // Node has not been initialized yet
        if (!get_option('stina_node_unique_id', false)) {
            $initializeNodeResponse = CrystalLiftService::instance()->openNodeInitializeNode();

            if ($initializeNodeResponse === false) {
                throw new Exception('Could not connect to the remote service for node initialization.');
            }

            update_option('stina_node_unique_id', $initializeNodeResponse['data']['nodeUniqueId']);
        }

        // Login the node
        $nodeUniqueId = get_option('stina_node_unique_id', false);

        if ($nodeUniqueId === false) {
            throw new Exception('The node has not yet been initialized.');
        }

        $loginNodeResponse = CrystalLiftService::instance()->openNodeLoginNode($nodeUniqueId);

        if (!$loginNodeResponse) {
            throw new Exception('The node could not be authenticated.');
        }
    }

    public static function createTables()
    {
        /** @var wpdb */
        global $wpdb;

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

        $table1 = $wpdb->prefix . self::CAMPAIGN_META_TABLE_NAME;
        $table2 = $wpdb->prefix . self::CAMPAIGN_TRIGGER_TABLE_NAME;
        $table3 = $wpdb->prefix . self::CAMPAIGN_RECIPIENT_REL_TABLE_NAME;

        dbDelta("
            CREATE TABLE IF NOT EXISTS $table1 (
                `id` BIGINT(20) UNSIGNED AUTO_INCREMENT,
                `campaign_unique_id` VARCHAR(255) NOT NULL,
                `meta_key` VARCHAR(255) NULL,
                `meta_value` LONGTEXT NULL,
                `created_at` DATETIME NULL,
                `created_by` BIGINT(20) UNSIGNED NULL DEFAULT NULL,
                `updated_at` DATETIME NULL DEFAULT NULL,
                `updated_by` BIGINT(20) UNSIGNED NULL DEFAULT NULL,
                PRIMARY KEY (`id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8
        ");

        dbDelta("
            CREATE TABLE IF NOT EXISTS {$table2} (
                `id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
                `campaign_unique_id` VARCHAR(255) NOT NULL,
                `trigger_unique_id` VARCHAR(255) NOT NULL,
                `variable_mapping` VARCHAR(4000) NOT NULL,
                `user_id` BIGINT(20) UNSIGNED NULL,
                `created_at` DATETIME NULL,
                `created_by` BIGINT(20) UNSIGNED NULL DEFAULT NULL,
                `updated_at` DATETIME NULL DEFAULT NULL,
                `updated_by` BIGINT(20) UNSIGNED NULL DEFAULT NULL,
                PRIMARY KEY (`id`),
                UNIQUE KEY (`trigger_unique_id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
        ");

        dbDelta("
            CREATE TABLE IF NOT EXISTS {$table3} (
                `id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
                `campaign_unique_id` VARCHAR(255) NOT NULL,
                `user_id` BIGINT(20) UNSIGNED NOT NULL,
                `created_at` DATETIME NULL,
                `created_by` BIGINT(20) UNSIGNED NULL DEFAULT NULL,
                `updated_at` DATETIME NULL DEFAULT NULL,
                `updated_by` BIGINT(20) UNSIGNED NOT NULL,
                PRIMARY KEY (`id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
        ");
    }
}