<?php


namespace STINA\CrystalLift\Widgets;

use DateTime;
use Exception;
use Psr\Http\Message\ResponseInterface;
use STINA\CrystalLift\Repositories\Resources\CampaignTrigger as CampaignTriggerResourceRepository;
use STINA\CrystalLift\Setup;
use STINA\Library\Abstracts\Widget as AbstractWidget;
use wpdb;

defined('ABSPATH') || exit;

class Advertisements extends AbstractWidget
{
    /**
     * @var bool|ResponseInterface
     */
    protected $recipients;

    /**
     * @var int
     */
    protected $count;

    /**
     * Advertisements constructor.
     */
    public function __construct()
    {
        /** @var wpdb $wpdb */
        global $wpdb;

        $this->recipients = array();
        $this->count = CampaignTriggerResourceRepository::instance()->count();

        $table = $wpdb->prefix . Setup::CAMPAIGN_TRIGGER_TABLE_NAME;
        $recipients = CampaignTriggerResourceRepository::instance()->query("
            SELECT * FROM
                {$table}
            WHERE
                1=1 
            ORDER BY
                created_at DESC
            LIMIT 5;
        ");

        if ($recipients) {
            $this->recipients = $recipients;
        }

        $this->name = __('Advertisement recipients', 'stina-crystal-lift');
        $this->body = $this->prepareBody();
        $this->footer = $this->prepareFooter();
    }

    /**
     * @return string
     */
    private function prepareBody()
    {
        $html = '';

        if (empty($this->recipients)) {
            $html .= '<p>';
            $html .= __('You currently do not have any advertisement recipients.', 'stina-crystal-lift');
            $html .= '</p>';
        } else {
            $html .= '
                <p class="stina-mt-0">
                    <strong style="font-size: 3em;">' . $this->count . '</strong>
                    <span>' . __('advertisement recipients', 'stina-crystal-lift') . '</span>
                </p>
            ';

            $html .= '<hr>';
            $html .= '<p>';
            $html .= '<h3 style="font-size: 1.2em;">' . __('Newest advertisement recipients', 'stina-crystal-lift') . '</h3>';

            $html .= '<ul>';

            $html .= '
                <li class="stina-flexbox stina-mt-1">
                    <strong class="stina-w-12">' . __('Date', 'stina-crystal-lift') .'</strong>
                    <strong class="stina-w-12">' . __('User', 'stina-crystal-lift') .'</strong>
                </li>
            ';

            foreach ($this->recipients as $recipient) {
                $html .= '
                    <li class="stina-flexbox" style="padding: 5px 0">
                        <span class="stina-w-12">' . $this->getFormattedDate($recipient->created_at) . '</span>
                        <span class="stina-w-12">' . $this->getUserEditLink($recipient->user_id) . '</span>
                    </li>
                ';
            }

            $html .= '</ul>';
            $html .= '</p>';

        }

        return $html;
    }

    /**
     * @return string
     */
    private function prepareFooter()
    {
        $html = false;

        return $html;
    }

    /**
     * Returns the amount of all advertisement recipients
     *
     * @return int
     */
    private function getActiveAdvertisementCount()
    {
        return $this->recipients['total'];
    }

    /**
     * Returns a formatted datetime string.
     *
     * @param string $date
     * @return string
     */
    private function getFormattedDate($date)
    {
        try {
            $date = new DateTime($date);
        } catch (Exception $e) {
            return __('Unknown', 'stina-crystal-lift');
        }

        return $date->format('d.m.Y, H:i:s');
    }

    private function getUserEditLink($userId)
    {
        $user = get_user_by('ID', $userId);

        if (!$user) {
            return __("User with ID: #{$userId} not found", 'stina-crystal-lift');
        }

        return sprintf(
            '<a href="%s">%s</a>',
            get_edit_user_link($userId),
            $user->display_name
        );
    }

    /**
     * Returns the concatenated first and last name of a customer.
     *
     * @param array $customer
     * @return string
     */
    private function getCustomerFullName($customer)
    {
        return $customer['firstName'] . ' ' . $customer['lastName'];
    }

    /**
     * Returns the full country name fetched by its ISO2 code.
     *
     * @param string $iso2
     * @return string
     */
    private function getCountryName($iso2)
    {
        return stina_get_country_name($iso2);
    }
}