<?php


namespace STINA\CrystalLift\Widgets;

use Psr\Http\Message\ResponseInterface;
use STINA\CrystalLift\Enumerators\CampaignAction;
use STINA\CrystalLift\Enumerators\CampaignProvider;
use STINA\CrystalLift\Enumerators\CampaignStatus;
use STINA\CrystalLift\Enumerators\Page;
use STINA\CrystalLift\Services\CrystalLift as CrystalLiftService;
use STINA\Library\Abstracts\Widget as AbstractWidget;

defined('ABSPATH') || exit;

class Campaigns extends AbstractWidget
{
    /**
     * @var bool|ResponseInterface
     */
    protected $activeCampaigns;

    /**
     * @var bool|array
     */
    protected $newestCampaigns;

    /**
     * Campaigns constructor.
     */
    public function __construct()
    {
        $this->activeCampaigns = array(
            'total' => 0,
            'list' => array()
        );

        $activeCampaigns = CrystalLiftService::instance()->userCampaignListCampaign(
            1,
            10000,
            array(),
            array(
                array(
                    'key' => 'campaignStatus',
                    'value' => CampaignStatus::CAMPAIGN_ACTIVE
                )
            ),
            null
        );

        $newestCampaigns = CrystalLiftService::instance()->userCampaignListCampaign(
            1,
            5,
            array(),
            array(),
            null
        );

        if ($activeCampaigns) {
            $this->activeCampaigns = $activeCampaigns['data'];
        }

        if ($newestCampaigns) {
            $this->newestCampaigns = $newestCampaigns['data'];
        }

        $this->name = __('Campaigns', 'stina-crystal-lift');
        $this->body = $this->prepareBody();
        $this->footer = $this->prepareFooter();
    }

    /**
     * @return string
     */
    private function prepareBody()
    {
        $html = '';

        $html .= '
            <p class="stina-mt-0">
                <strong style="font-size: 3em;">' . $this->getActiveCampaignCount() . '</strong>
                <span>' . __('active campaigns', 'stina-crystal-lift') . '</span>
            </p>
        ';

        $html .= '<hr>';

        if ($this->newestCampaigns) {
            $html .= '<h3 style="font-size: 1.2em;">' . __('Newest campaigns', 'stina-crystal-lift') . '</h3>';

            $html .= '<ul>';
            $html .= '
                <li class="stina-flexbox stina-mt-1">
                    <strong class="stina-w-12">' . __('Name', 'stina-crystal-lift') .'</strong>
                    <strong class="stina-w-12">' . __('Action', 'stina-crystal-lift') .'</strong>
                    <strong class="stina-w-12">' . __('Provider', 'stina-crystal-lift') .'</strong>
                </li>
            ';

            foreach ($this->newestCampaigns['list'] as $i => $campaign) {

                if ($i >= 5) {
                    break;
                }

                $html .= '
                    <li class="stina-flexbox" style="padding: 5px 0">
                        <strong class="stina-w-12">
                            <a href="' . esc_url(admin_url('admin.php?page=' . Page::CAMPAIGNS . '&id=' . $campaign['campaignUniqueId'])) . '">
                                ' . esc_html__($campaign['campaignDescLong']) . '
                            </a>
                        </strong>
                        <span class="stina-w-12">' . CampaignAction::label($campaign['actions'][0]['actionDescShort']) . '</span>
                        <span class="stina-w-12">' . CampaignProvider::label($campaign['actions'][0]['provider']['providerDescShort']) . '</span>
                    </li>
                ';
            }

            $html .= '</ul>';

            $html .= '<p class="stina-mt-2">';
            $html .= '<a href="' . esc_url(admin_url('admin.php?page=' . Page::CAMPAIGNS)) . '">' . __('Show all campaigns', 'stina-crystal-lift') . '</a>';
            $html .= '</p>';
        } else {
            $html .= '<h3>' . __('No campaigns found', 'stina-crystal-lift') . '.</h3>';
        }


        return $html;
    }

    /**
     * Prepares the widget's footer html markup.
     *
     * @return string
     */
    private function prepareFooter()
    {
        return false;
    }

    /**
     * Returns the amount of all currently active campaigns.
     *
     * @return int
     */
    private function getActiveCampaignCount()
    {
        return $this->activeCampaigns['total'];
    }
}