<?php

use STINA\Library\Alert;

defined('ABSPATH') || exit;

if (!function_exists('stina_get_template')) {
    /**
     * @param string $template   Path to the template, relative to the plugin's templates directory
     * @param string $pluginDir  Plugin directory path
     * @param string $pluginSlug Plugin slug
     * @param array  $args       Additional variables passed to the template
     * @return bool|void
     */
    function stina_get_template($template, $pluginDir, $pluginSlug, $args = array()) {
        $filePath       = false;
        $filePathPlugin = $pluginDir . '/templates/' . $template;
        $filePathTheme  = get_stylesheet_directory() . '/' . $pluginSlug . '/' . $template;

        if (file_exists($filePathTheme)) {
            $filePath = $filePathTheme;
        }

        if (!$filePath) {
            if (file_exists($filePathPlugin)) {
                $filePath = $filePathPlugin;
            } else {
                return false;
            }
        }

        if (is_array($args) && !empty($args)) {
            extract($args, EXTR_OVERWRITE);
        }

        include $filePath;
    }
}

if (!function_exists('stina_plugin_is_active')) {
    /**
     * @param string $plugin
     * @return bool
     */
    function stina_plugin_is_active($plugin) {
        return in_array("{$plugin}/{$plugin}.php", apply_filters('active_plugins', get_option('active_plugins')));
    }
}

if (!function_exists('stina_get_country_name')) {
    /**
     * @param string $iso2
     * @return string
     */
    function stina_get_country_name($iso2) {
        if (stina_plugin_is_active('woocommerce')) {
            return WC()->countries->countries[$iso2];
        }

        return $iso2;
    }
}

if (!function_exists('stina_get_utc_date_time')) {
    /**
     * @param string      $dateTimeString
     * @param null|string $modify
     * @return false|DateTime
     */
    function stina_get_utc_date_time($dateTimeString = 'now', $modify = null) {
        try {
            $utcDateTime = new DateTime($dateTimeString, new DateTimeZone('UTC'));
        } catch (Exception $e) {
            return false;
        }

        if ($modify === null) {
            return $utcDateTime;
        }

        $utcDateTime->modify($modify);

        return $utcDateTime;
    }
}

if (!function_exists('stina_alerts')) {
    function stina_alerts() {
        foreach (Alert::getTypes() as $type => $class) {
            $messages = get_transient('stina_alert_' . $type);

            if ($messages && is_array($messages)) {
                foreach ($messages as $message) {
                    echo sprintf(
                        Alert::getAlert(),
                        $class,
                        $message
                    );
                }

                delete_transient('stina_alert_' . $type);
            }
        }
    }
}

if (!function_exists('stina_get_gravatar_image_url')) {
    function stina_get_gravatar_image_url($email, $size = 64) {
        return 'https://www.gravatar.com/avatar/' . md5(strtolower(trim($email))) . "?s=" . intval($size);
    }
}