<?php

namespace STINA\Library;

defined('ABSPATH') || exit;

class Alert
{
    const ALERT_PRIMARY   = 'stina-alert-primary';
    const ALERT_SECONDARY = 'stina-alert-secondary';
    const ALERT_SUCCESS   = 'stina-alert-success';
    const ALERT_DANGER    = 'stina-alert-danger';
    const ALERT_WARNING   = 'stina-alert-warning';
    const ALERT_INFO      = 'stina-alert-info';
    const ALERT_LIGHT     = 'stina-alert-light';
    const ALERT_DARK      = 'stina-alert-dark';

    /**
     * Alert constructor.
     */
    public function __construct()
    {
        //add_action('admin_notices', array($this, 'init'));
    }

    /**
     * Retrieves the alerts from the transient, displays them and finally
     * deletes them.
     */
    public function init()
    {
        foreach (self::getTypes() as $type => $class) {
            $messages = get_transient('stina_alert_' . $type);

            if ($messages && is_array($messages)) {
                foreach ($messages as $message) {
                    echo sprintf(
                        self::getAlert(),
                        $class,
                        $message
                    );
                }

                delete_transient('stina_alert_' . $type);
            }
        }
    }

    /**
     * Adds a dashboard notice to be displayed on the next page reload.
     *
     * @param string $level
     * @param string $message
     * @param int    $code
     * @param int    $duration
     */
    public static function add($level, $message, $code = 0, $duration = 60)
    {
        $messages = get_transient('stina_alert_' . $level);

        if ($messages && is_array($messages)) {
            $messages[] = $message;
        } else {
            $messages = array($message);
        }

        set_transient('stina_alert_' . $level, $messages, $duration);
    }

    /**
     * Returns all alert types and their classes.
     *
     * @return string[]
     */
    public static function getTypes()
    {
        return array(
            'primary'   => self::ALERT_PRIMARY,
            'secondary' => self::ALERT_SECONDARY,
            'success'   => self::ALERT_SUCCESS,
            'danger'    => self::ALERT_DANGER,
            'warning'   => self::ALERT_WARNING,
            'info'      => self::ALERT_INFO,
            'light'     => self::ALERT_LIGHT,
            'dark'      => self::ALERT_DARK
        );
    }

    /**
     * Returns the alert's HTML markup.
     *
     * @return string
     */
    public static function getAlert()
    {
        return '
            <div class="stina-alert %s stina-alert-dismissible fade show" role="alert">
              %s
              <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                <span aria-hidden="true">&times;</span>
              </button>
            </div>
        ';
    }

    /**
     * Displays a primary message.
     *
     * @param string $message
     */
    public static function primary($message)
    {
        self::add('primary', $message);
    }

    /**
     * Displays a secondary message.
     *
     * @param string $message
     */
    public static function secondary($message)
    {
        self::add('secondary', $message);
    }

    /**
     * Displays a success message.
     *
     * @param string $message
     */
    public static function success($message)
    {
        self::add('success', $message);
    }

    /**
     * Displays a danger message.
     *
     * @param string $message
     */
    public static function danger($message)
    {
        self::add('danger', $message);
    }

    /**
     * Displays a warning message.
     *
     * @param string $message
     */
    public static function warning($message)
    {
        self::add('warning', $message);
    }

    /**
     * Displays a info message.
     *
     * @param string $message
     */
    public static function info($message)
    {
        self::add('info', $message);
    }

    /**
     * Displays a light message.
     *
     * @param string $message
     */
    public static function light($message)
    {
        self::add('light', $message);
    }

    /**
     * Displays a dark message.
     *
     * @param string $message
     */
    public static function dark($message)
    {
        self::add('dark', $message);
    }
}
