<?php


namespace STINA\Library;

defined('ABSPATH') || exit;

class Assets
{
    /**
     * Handles all JavaScript file registration.
     *
     * @var string $pluginUrl
     * @return void
     */
    public function registerJavaScript($pluginUrl)
    {
        // Select2
        if (!wp_script_is('stina-select2', 'registered')) {
            wp_register_script(
                'stina-select2',
                'https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/js/select2.min.js',
                array(),
                '4.1.0'
            );
        }

        // Moment.js
        if (!wp_script_is('stina-moment.js', 'registered')) {
            wp_register_script(
                'stina-moment.js',
                $pluginUrl . '/lib/assets/js/moment-2.25.3.min.js',
                array(),
                '2.25.3'
            );
        }

        // Font Awesome
        if (!wp_script_is('stina-fontawesome', 'registered')) {
            wp_register_script(
                'stina-fontawesome',
                $pluginUrl . '/lib/assets/js/fontawesome/all.min.js',
                array(),
                '5.13.0'
            );
        }

        // STINA Framework
        if (!wp_script_is('stina-framework', 'registered')) {
            wp_register_script(
                'stina-framework',
                $pluginUrl . '/lib/assets/js/stina-framework.js',
                array('jquery')
            );
        }

        // Vue.js production
        if (!wp_script_is('stina-vue.js', 'registered')) {
            wp_register_script(
                'stina-vue.js',
                $pluginUrl . '/lib/assets/js/vue-2.6.11.js',
                array(),
                '2.6.11'
            );
        }

        // Vue.js development
        if (!wp_script_is('stina-vue.js-dev', 'registered')) {
            wp_register_script(
                'stina-vue.js-dev',
                $pluginUrl . '/lib/assets/js/vue-2.6.11-dev.js',
                array()
            );
        }

        // Vue.js component - STINA Pagination
        if (!wp_script_is('stina-vue-component-pagination', 'registered')) {
            wp_register_script(
                'stina-vue-component-pagination',
                $pluginUrl . 'lib/assets/js/stina-vue-component-pagination.js',
                array('stina-vue.js-dev')
            );
        }

        // Vue.js component - STINA selectWoo Wrapper
        if (!wp_script_is('stina-vue-component-select2', 'registered')) {
            wp_register_script(
                'stina-vue-component-select2',
                $pluginUrl . 'lib/assets/js/stina-vue-component-select2.js',
                array('stina-vue.js-dev', 'jquery', 'stina-select2')
            );
        }

    }

    /**
     * Handles all CSS file registration
     *
     * @var string $pluginUrl
     * @return void
     */
    public function registerStylesheets($pluginUrl)
    {
        if (!wp_style_is('stina-select2', 'registered')) {
            wp_register_style(
                'stina-select2',
                'https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/css/select2.min.css',
                array(),
                '4.1.0'
            );
        }

        if (!wp_style_is('stina-fonts', 'registered')) {
            wp_register_style(
                'stina-fonts',
                $pluginUrl . 'lib/assets/css/stina-fonts.css',
                array(),
                '0.1.0'
            );
        }

        if (!wp_style_is('stina-framework', 'registered')) {
            wp_register_style(
                'stina-framework',
                $pluginUrl . 'lib/assets/css/stina-framework.css',
                array('stina-fonts'),
                '0.1.0'
            );
        }
    }
}