<?php


namespace STINA\Library;

use GuzzleHttp\Client;
use GuzzleHttp\RequestOptions;
use STINA\Library\Interfaces\Connector as ConnectorInterface;

defined('ABSPATH') || exit;

class Connector implements ConnectorInterface
{
    /**
     * @var string
     */
    protected $baseUri;

    /**
     * @var string
     */
    protected $version;

    /**
     * @var string
     */
    protected $portfolio;

    /**
     * @var Client
     */
    protected $client;

    /**
     * @var array
     */
    protected $headers;

    /**
     * @var array
     */
    protected $query;

    /**
     * Connector constructor.
     *
     * @param string $baseUri   The service base URI
     * @param string $portfolio The service portfolio element number
     * @param string $version   The service version
     * @param array  $config    Additional GuzzleHttp/Client() configuration
     */
    public function __construct($baseUri, $portfolio, $version, $config = array())
    {
        $this->baseUri = $baseUri;
        $this->version = $version;
        $this->portfolio = $portfolio;
        $this->headers = array(
            'Cache-Control'    => 'no-cache',
            'Content-Type'     => 'application/json',
            'Encryption-Level' => '0',
            'Encryption-Key'   => '0'
        );

        $config = array_merge(
            array(
                'base_uri' => $baseUri . '/' . $version
            ),
            $config
        );

        $this->client = new Client($config);
    }

    /**
     * @inheritDoc
     */
    public function createInfoObject($type, $feature, $mode, $data)
    {
        return array(
            'header' => array(
                'version'  => '1.0.2',
                'id'       => Uuid::v4(),
                'parentId' => '',
                'type'     => 'INFO_OBJECT_DEFAULT',
                'status'   => 'NEW',
                'history'  => array(
                    array(
                        'step'      => '1',
                        'timestamp' => gmdate('Y-m-d H:i:s.u'),
                        'unit'      => Uuid::v4(),
                        'type'      => 'SERVICE_REQUEST',
                        'status'    => 'NEW'
                    )
                )
            ),
            'payload' => array(
                'type'    => $type,
                'feature' => $feature,
                'mode'    => $mode,
                'data'    => $data
            )
        );
    }

    /**
     * @inheritDoc
     */
    public function request($body, $auth = false, $token = false, $method = 'POST')
    {
        $options = array(
            RequestOptions::VERIFY  => false,
            RequestOptions::HEADERS => $this->headers,
            RequestOptions::JSON    => $body
        );

        if ($auth !== 'false' && $token !== false && is_string($token)) {
            $options[RequestOptions::HEADERS]['Authorization'] = $auth . ' ' . $token;
        }

        $uri = "/{$this->portfolio}/info/{$this->version}";

        return $this->client->request($method, $uri, $options);
    }
}