<?php


namespace STINA\Library;

use STINA\Library\Abstracts\Singleton;

defined('ABSPATH') || exit;

class Package extends Singleton
{
    /**
     * @var bool
     */
    protected $loaded = false;

    /**
     * @var string
     */
    private $pluginUrl;

    /**
     * @param string $pluginDir The plugin directory which is calling the shared library
     * @param string $pluginUrl The plugin URL which is calling the shared library
     * @return void
     */
    public function bootstrap($pluginDir, $pluginUrl)
    {
        $this->pluginUrl = $pluginUrl;

        new Alert();

        add_action('admin_enqueue_scripts', array($this, 'enqueueScripts'));
        add_action('wp_enqueue_scripts',    array($this, 'enqueueScripts'));

        if (file_exists($pluginDir . '/lib/functions/stina-core-functions.php')) {
            require_once $pluginDir . '/lib/functions/stina-core-functions.php';
            $this->loaded = true;
        }
    }

    /**
     * Registers the library assets.
     *
     * @return void
     */
    public function enqueueScripts()
    {
        /** @var Assets $assets */
        $assets = new Assets();

        $assets->registerJavaScript($this->pluginUrl);
        $assets->registerStylesheets($this->pluginUrl);
    }

    /**
     * @return bool
     */
    public function isLoaded()
    {
        return $this->loaded;
    }
}