<?php


namespace STINA\Library\Repositories;

use STINA\Library\Abstracts\Singleton;
use STINA\Library\Models\User as UserModel;

defined('ABSPATH') || exit;

class User extends Singleton
{
    /**
     * Retrieves the STINA user for the currently logged in user.
     *
     * @return false|UserModel
     */
    public function get()
    {
        $userData = get_option('stina_user', false);

        if (!$userData) {
            return false;
        }

        $user = new UserModel();

        $user->setUniqueId($userData['uniqueId']);
        $user->setUsername($userData['username']);
        $user->setEmail($userData['email']);
        $user->setFirstName($userData['firstName']);
        $user->setLastName($userData['lastName']);

        return $user;
    }

    /**
     * Stores a new STINA user to the currently logged in user's meta.
     *
     * @param array $userData
     * @return false|UserModel
     */
    public function set($userData)
    {
        $user = new UserModel();

        $update = update_option( 'stina_user', $userData, true);

        if (!$update) {
            return false;
        }

        $user->setUniqueId($userData['uniqueId']);
        $user->setEmail($userData['email']);

        return $user;
    }

    /**
     * Deletes the currently logged in user account from the user meta table.
     *
     * @param string|null $plugin
     * @return bool
     */
    public function delete($plugin)
    {
        $deleteUser = delete_option('stina_user');
        $deleteUserToken = delete_transient('stina_user_token');

        if ($plugin !== null && is_string($plugin)) {
            delete_option($plugin . '_user_api_key');
            delete_option($plugin . '_user_api_secret');
        }

        return $deleteUser && $deleteUserToken;
    }
}