<?php

use STINA\CrystalLift\Enumerators\CampaignEventObject;

defined('ABSPATH') || exit;

/**
 * @var array $campaignEventConfig
 */

?>

<div class="row boxed stina-pt-3">
    <div class="col-12">
        <h2><?php _e('Configure campaign event', 'stina-crystal-lift'); ?></h2>
        <p class="stina-mb-0"><?php _e('Events can be further configured to suit your marketing strategy.', 'stina-crystal-lift'); ?></p>
    </div>
</div>

<div class="row boxed">
    <div class="col-12">

        <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" method="post">
            <input type="hidden" name="action" value="crysli_campaign_update_event">
            <?php wp_nonce_field('crysli_campaign_update_event'); ?>
            <input type="hidden" name="campaign_unique_id" v-model="campaign.data.campaignUniqueId">
            <input type="hidden" name="campaign_desc_long" v-model="campaign.data.campaignDescLong">
            <input type="hidden" name="campaign_event_unique_id" v-model="campaign.data.events[0].eventUniqueId" v-if="campaign.data.events.length > 0">
            <input type="hidden" name="campaign_type" v-model="campaign.data.campaignType">
            <input type="hidden" name="campaign_status" v-model="campaign.data.campaignStatus">

            <!-- Campaign Event Object -->
            <div class="stina-form-group">
                <label for="crysli-campaign-event-object">
                    <strong><?php _e('Object', 'stina-crystal-lift'); ?></strong>
                </label>
                <select id="crysli-campaign-event-object"
                        class="stina-form-control"
                        name="campaign_event_object"
                        @change="onSelectObject"
                        v-model="active.object">
                    <option value="">-- <?php _e('Please select'); ?> --</option>
                    <option value="<?php echo esc_attr(CampaignEventObject::CUSTOMER); ?>">
                        <?php _e('Customer', 'stina-crystal-lift'); ?>
                    </option>
                    <option value="<?php echo esc_attr(CampaignEventObject::ORDER); ?>">
                        <?php _e('Order', 'stina-crystal-lift'); ?>
                    </option>
                </select>
            </div>

            <!-- Campaign Event Trigger -->
            <div class="stina-form-group">
                <label for="crysli-campaign-event-trigger">
                    <strong><?php _e('Trigger', 'stina-crystal-lift'); ?></strong>
                </label>
                <select id="crysli-campaign-event-trigger"
                        class="stina-form-control"
                        name="campaign_event_trigger"
                        @change="onSelectEvent"
                        v-model="active.trigger">
                    <option value="">-- <?php _e('Please select'); ?> --</option>
                    <option v-for="event in events" :value="event.key">{{ event.value }}</option>
                </select>
            </div>

            <div class="stina-form-group">
                <label><strong><?php _e('Conditions', 'stina-crystal-lift'); ?></strong></label>

                <div class="stina-list-group">

                    <!-- Already active conditions -->
                    <div v-for="(activeCondition, i) in active.conditions"
                         class="stina-list-group-item stina-flexbox stina-w-12"
                         :key="'crysli-condition-active' + i"
                         v-if="active.object && active.trigger">

                        <!-- ENTITY -->
                        <div style="flex-basis: 25%" class="stina-mr-1">
                            <select id=""
                                    class="stina-form-control"
                                    :name="'campaign_event_conditions[' + i + '][entity]'"
                                    v-model="activeCondition.entity"
                                    @change="activeCondition.value = null">
                                <option :value="availableCondition.entity.value"
                                        v-for="(availableCondition, j) in conditions"
                                        :key="'crysli-condition-active-entity' + j">
                                    {{ availableCondition.entity.label }}
                                </option>
                            </select>
                        </div>

                        <!-- OPERATOR -->
                        <div style="flex-basis: 25%" class="stina-mr-1">
                            <select id=""
                                    class="stina-form-control"
                                    :name="'campaign_event_conditions[' + i + '][operator]'"
                                    v-model="activeCondition.operator">
                                <option :value="availableOperator"
                                        v-for="(availableOperator, k) in getConditionOperators(activeCondition.entity)"
                                        :key="'crysli-condition-active-operator' + k">
                                    {{ i18n.operators[availableOperator] }}
                                </option>
                            </select>
                        </div>

                        <!-- VALUE -->
                        <div style="flex: 50%" class="modal" :class="'stina-select2-container-' + i">
                            <stina-select2 :index="i"
                                           class="stina-form-control stina-form-control-select2"
                                           selection-css-class="stina-select2-selection"
                                           dropdown-css-class="stina-select2-dropdown"
                                           :name="'campaign_event_conditions[' + i + '][value][]'"
                                           :ajax="getConditionAjaxProp(activeCondition.entity)"
                                           :allow-clear="true"
                                           :placeholder="getConditionDropdownProp(activeCondition.entity)"
                                           :multiple="true"
                                           :minimum-input-length="0"
                                           :value="activeCondition.value"
                                           style="position: relative;"
                                           @input="onUpdateConditionValue">

                                <?php if ($campaignEventConfig): ?>

                                    <?php if ($campaignEventConfig['conditions'][0]['entity'] === 'product'): ?>

                                        <?php foreach ($campaignEventConfig['conditions'][0]['value'] as $value): ?>

                                            <option value="<?php echo esc_attr($value); ?>" selected="selected"><?php echo $value; ?></option>

                                        <?php endforeach; ?>

                                    <?php else: ?>

                                        <?php foreach ($campaignEventConfig['conditions'][0]['value'] as $value): ?>

                                            <option value="<?php echo esc_attr($value); ?>" selected="selected"><?php echo WC()->countries->countries[$value]; ?></option>

                                        <?php endforeach; ?>

                                    <?php endif; ?>

                                <?php endif; ?>

                            </stina-select2>
                        </div>
                    </div>

                </div>

            </div>

            <button class="stina-btn stina-btn-primary" type="submit">
                <i class="fas fa-save" style="margin-right: .25em"></i>
                <?php _e('Save', 'stina-crystal-lift'); ?>
            </button>

        </form>

    </div>
</div>
