<?php

use STINA\Library\Models\User as UserModel;

defined('ABSPATH') || exit;

/**
 * @var array     $campaign
 * @var UserModel $user
 */

?>

<div v-if="selected.campaignType === 'CAMPAIGN_TYPE_DP_TRIGGER_DIALOG_NEW'">
    <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" method="post">
        <input type="hidden" name="action" value="crysli_campaign_update_action">
        <input type="hidden" name="campaign_id" value="<?php echo esc_attr($campaign['campaignUniqueId']); ?>">
        <?php wp_nonce_field('crysli_campaign_update_action'); ?>

        <div class="row boxed stina-pt-3">
            <div class="col-12">
                <h2><?php _e('Campaign details'); ?></h2>
                <p class="stina-mb-0"><?php _e('For the campaign to work, you will need to configure the campaign\'s <b>variables</b>.', 'stina-crystal-lift'); ?></p>
            </div>
        </div>

        <div class="row boxed">
            <div class="col-12">
                <div class="stina-form-group stina-mb-0">
                    <label for="campaign-name"><?php _e('Campaign name', 'stina-crystal-lift'); ?></label>
                    <input id="campaign-name"
                           class="stina-form-control stina-w-12"
                           name="campaign_name"
                           type="text"
                           required="required"
                           v-model="providers.DP_TRIGGER_DIALOG.campaignName"
                           pattern='[^<>?":|\\/*]{0,30}'
                           title="<?php esc_attr_e('30 characters maximum, the following special characters are not allowed: < > ? " : | \ / *', 'stina-crystal-lift'); ?>">
                </div>
            </div>
        </div>

        <div class="row boxed">
            <div class="col-12">
                <h2><?php _e('Required variables', 'stina-crystal-lift'); ?></h2>
                <p class="stina-mb-0"><?php _e('Each campaign must have at the very least its address variables defined. These are needed to make sure that the printed mail advertisement arrives at the recipient\'s address.', 'stina-crystal-lift'); ?></p>
            </div>
        </div>

        <!-- Mandatory variables -->
        <div class="row boxed">
            <div class="col-12">

                <ul class="stina-list-group stina-mt-0">

                    <li class="stina-list-group-item stina-flexbox dp-trigger-dialog-campaign-variable-heading">
                        <strong class="stina-mr-1"><?php _e('Field', 'stina-crystal-lift'); ?></strong>
                        <strong class="stina-mr-1"><?php _e('Variable name', 'stina-crystal-lift'); ?></strong>
                        <strong class="stina-mr-1"><?php _e('Variable type', 'stina-crystal-lift'); ?></strong>
                        <strong class=""><?php _e('Mapped to', 'stina-crystal-lift'); ?></strong>
                    </li>

                    <li class="stina-list-group-item stina-flexbox dp-trigger-dialog-campaign-variable"
                        v-if="providers.DP_TRIGGER_DIALOG.variables.mandatory.length > 0"
                        v-for="(variable, i) in providers.DP_TRIGGER_DIALOG.variables.mandatory"
                        :key="'variable-mandatory-' + variable.id">

                        <div class="stina-mr-1 variable-field">
                            <input type="hidden"
                                   :name="'campaign_variable[' + i + '][field]'"
                                   v-model="variable.field">
                            <strong>{{ i18n.variableMappingFields[variable.field] }}</strong>
                        </div>

                        <div class="stina-form-group stina-mb-0 stina-mr-1 variable-name">
                            <label :for="'campaign-variable-' + i + '-name'" class="sr-only">
                                <strong><?php _e('Variable name', 'stina-crystal-lift'); ?></strong>
                            </label>
                            <input :id="'campaign-variable-' + i + '-name'"
                                   class="stina-form-control stina-form-control-sm stina-w-12"
                                   :name="'campaign_variable[' + i + '][name]'"
                                   type="text"
                                   v-model="variable.name"
                                   required="required"
                                   maxlength="60">
                        </div>

                        <div class="variable-type stina-mr-1">
                            <div style="line-height: 30px;">
                                <input type="hidden"
                                       :name="'campaign_variable[' + i + '][type]'"
                                       v-model="variable.type">
                                <span>{{ variable.type }}</span>
                            </div>
                        </div>

                        <div class="variable-mapped-to">
                            <div class="stina-form-group stina-mb-0 stina-mr-1 stina-w-12">
                                <label :for="'campaign-variable-' + i + '-mapped-to'" class="sr-only">
                                    <strong><?php _e('Mapped to', 'stina-crystal-lift'); ?></strong>
                                </label>
                                <select :id="'campaign-variable-' + i + '-mapped-to'"
                                        class="stina-form-control stina-form-control-sm stina-w-12"
                                        :name="'campaign_variable[' + i + '][mapped_to]'"
                                        v-model="variable.mappedTo"
                                        required="required">
                                    <?php echo crysli_get_variable_mapping_options_html(); ?>
                                </select>
                                <input :id="'campaign-variable-' + i + '-value'"
                                       class="stina-form-control stina-form-control-sm stina-w-12"
                                       type="text"
                                       :name="'campaign_variable[' + i + '][value]'"
                                       v-if="variable.mappedTo === 'TEXT_FIELD'"
                                       v-model="variable.value"
                                       required="required">
                            </div>
                        </div>
                    </li>

                </ul>

            </div>
            <div class="col-12">
                <p class="stina-mb-0 stina-text-muted"><?php _e('Please note that the recipient will be skipped if he doesn\'t have a <b>Company name</b> nor a combination of <b>First and last name</b>.'); ?></p>
            </div>
        </div>

        <!-- Additional variables -->
        <div class="row boxed">

            <div class="col-12">
                <h2><?php _e('Additional variables', 'stina-crystal-lift'); ?></h2>
                <p class="stina-mb-0"><?php _e('You can add additional variables to further customize the look of your printed mail advertisement.', 'stina-crystal-lift'); ?></p>
            </div>

            <div class="col-12">
                <ul class="stina-list-group stina-mt-0"
                    v-if="providers.DP_TRIGGER_DIALOG.variables.existing.length > 0 || providers.DP_TRIGGER_DIALOG.variables.new.length > 0">

                    <li class="stina-list-group-item stina-flexbox dp-trigger-dialog-campaign-variable-heading">
                        <strong class="stina-mr-1"><?php _e('Variable name', 'stina-crystal-lift'); ?></strong>
                        <strong class="stina-mr-1"><?php _e('Variable type', 'stina-crystal-lift'); ?></strong>
                        <strong class=""><?php _e('Mapped to', 'stina-crystal-lift'); ?></strong>
                    </li>

                    <!-- Existing variables -->
                    <li class="stina-list-group-item"
                        v-if="providers.DP_TRIGGER_DIALOG.variables.existing.length > 0"
                        v-for="(variable, j) in providers.DP_TRIGGER_DIALOG.variables.existing"
                        :key="'variable-existing-' + variable.id">

                        <div class="stina-flexbox dp-trigger-dialog-campaign-variable">

                            <div class="stina-form-group stina-mb-0 stina-mr-1">
                                <label :for="'campaign-variable-' + getExistingVariableCount(j) + '-name'" class="sr-only">
                                    <strong><?php _e('Variable name', 'stina-crystal-lift'); ?></strong>
                                </label>
                                <input :id="'campaign-variable-' + getExistingVariableCount(j) + '-name'"
                                       class="stina-form-control stina-form-control-sm stina-w-12"
                                       :name="'campaign_variable[' + getExistingVariableCount(j) + '][name]'"
                                       type="text"
                                       v-model="variable.name"
                                       required="required"
                                       maxlength="60">
                            </div>

                            <div class="stina-form-group stina-mb-0 stina-mr-1">
                                <label :for="'campaign-variable-' + getExistingVariableCount(j) + '-type'" class="sr-only">
                                    <strong><?php _e('Variable type', 'stina-crystal-lift'); ?></strong>
                                </label>
                                <select :id="'campaign-variable-' + getExistingVariableCount(j) + '-type'"
                                        class="stina-form-control stina-form-control-sm stina-w-12"
                                        :name="'campaign_variable[' + getExistingVariableCount(j) + '][type]'"
                                        v-model="variable.type"
                                        required="required">
                                    <?php echo crysli_get_trigger_dialog_variable_type_options_html(); ?>
                                </select>
                            </div>

                            <div class="stina-flexbox">
                                <div class="stina-form-group stina-mb-0 stina-mr-1 stina-w-12">
                                    <label :for="'campaign-variable-' + getExistingVariableCount(j) + '-mapped-to'" class="sr-only">
                                        <strong><?php _e('Mapped to', 'stina-crystal-lift'); ?></strong>
                                    </label>
                                    <select :id="'campaign-variable-' + getExistingVariableCount(j) + '-mapped-to'"
                                            class="stina-form-control stina-form-control-sm"
                                            :name="'campaign_variable[' + getExistingVariableCount(j) + '][mapped_to]'"
                                            v-model="variable.mappedTo"
                                            required="required">
                                        <?php echo crysli_get_variable_mapping_options_html(); ?>
                                    </select>
                                    <input :id="'campaign-variable-' + j + '-value'"
                                           class="stina-form-control stina-form-control-sm"
                                           type="text"
                                           :name="'campaign_variable[' + getExistingVariableCount(j) + '][value]'"
                                           v-if="variable.mappedTo === 'TEXT_FIELD'"
                                           v-model="variable.value"
                                           required="required">
                                </div>

                                <div>
                                    <button type="button"
                                            class="stina-btn stina-btn-primary stina-m-0"
                                            @click="onRemoveVariable(variable.id, 'existing')"
                                            title="<?php esc_attr_e('Delete', 'stina-crystal-lift'); ?>">
                                        <span class="sr-only"><?php _e('Delete variable', 'stina-crystal-lift'); ?></span>
                                        <i class="fas fa-trash" aria-hidden="true"></i>
                                    </button>
                                </div>
                            </div>

                        </div>
                    </li>

                    <!-- New variables -->
                    <li class="stina-list-group-item stina-flexbox dp-trigger-dialog-campaign-variable"
                        v-for="(variable, k) in providers.DP_TRIGGER_DIALOG.variables.new"
                        :key="'variable-new-' + variable.id">

                        <div class="stina-form-group stina-mb-0 stina-mr-1">
                            <label :for="'campaign-variable-' + getNewVariableCount(k) + '-name'" class="sr-only">
                                <strong><?php _e('Variable name', 'stina-crystal-lift'); ?></strong>
                            </label>
                            <input :id="'campaign-variable-' + getNewVariableCount(k) + '-name'"
                                   class="stina-form-control stina-form-control-sm stina-w-12"
                                   :name="'campaign_variable[' + getNewVariableCount(k) + '][name]'"
                                   type="text"
                                   v-model="variable.name"
                                   required="required">
                        </div>

                        <div class="stina-form-group stina-mb-0 stina-mr-1">
                            <label :for="'campaign-variable-' + getNewVariableCount(k) + '-type'" class="sr-only">
                                <strong><?php _e('Variable type', 'stina-crystal-lift'); ?></strong>
                            </label>
                            <select :id="'campaign-variable-' + getNewVariableCount(k) + '-type'"
                                    class="stina-form-control stina-form-control-sm stina-w-12"
                                    :name="'campaign_variable[' + getNewVariableCount(k) + '][type]'"
                                    v-model="variable.type"
                                    required="required">
                                <?php echo crysli_get_trigger_dialog_variable_type_options_html(); ?>
                            </select>
                        </div>

                        <div class="stina-flexbox">
                            <div class="stina-form-group stina-mb-0 stina-mr-1 stina-w-12">
                                <label :for="'campaign-variable-' + getNewVariableCount(k) + '-mapped-to'" class="sr-only">
                                    <strong><?php _e('Mapped to', 'stina-crystal-lift'); ?></strong>
                                </label>
                                <select :id="'campaign-variable-' + getNewVariableCount(k) + '-mapped-to'"
                                        class="stina-form-control stina-form-control-sm"
                                        :name="'campaign_variable[' + getNewVariableCount(k) + '][mapped_to]'"
                                        v-model="variable.mappedTo"
                                        required="required">
                                    <?php echo crysli_get_variable_mapping_options_html(); ?>
                                </select>
                                <input :id="'campaign-variable-' + k + '-value'"
                                       class="stina-form-control stina-form-control-sm"
                                       type="text"
                                       :name="'campaign_variable[' + getNewVariableCount(k) + '][value]'"
                                       v-if="variable.mappedTo === 'TEXT_FIELD'"
                                       v-model="variable.value"
                                       required="required">
                            </div>

                            <div>
                                <button type="button"
                                        class="stina-btn stina-btn-primary stina-m-0"
                                        @click="onRemoveVariable(variable.id, 'new')"
                                        title="<?php esc_attr_e('Delete', 'stina-crystal-lift'); ?>">
                                    <span class="sr-only"><?php _e('Delete variable', 'stina-crystal-lift'); ?></span>
                                    <i class="fas fa-trash" aria-hidden="true"></i>
                                </button>
                            </div>
                        </div>
                    </li>

                </ul>

                <div class="stina-mt-1 stina-text-right">
                    <button type="button"
                            class="stina-btn stina-btn-primary stina-m-0"
                            @click="onAddVariable"><?php _e('Add variable', 'stina-crystal-lift'); ?></button>
                </div>

            </div>

        </div>
        <div class="row boxed stina-pb-3">

            <div class="col-12">
                <p class="stina-text-muted stina-mb-1"><?php _e('Please be aware that the campaign variables can not be updated if the campaign inside the <strong>Deutsche Post Print-Mailing Automation</strong> Dashboard is set to "Active". To update the campaign variables in this case, you first need to pause the corresponding campaign.'); ?></p>

                <button type="submit" class="stina-btn stina-btn-primary">
                    <span v-if="campaign.actions[0].config === null"><?php _e('Add content', 'stina-crystal-lift'); ?></span>
                    <span v-else><?php _e('Update', 'stina-crystal-lift'); ?></span>
                </button>
            </div>
        </div>
    </form>
</div>
