<?php

use STINA\CrystalLift\Models\Campaign as CampaignModel;
use STINA\Library\Models\User as UserModel;

defined('ABSPATH') || exit;

/**
 * @var CampaignModel $campaign
 * @var UserModel $user
 */

?>

<div class="row boxed stina-pt-3">
    <div class="col-12">
        <h2><?php _e('Select the campaign recipients'); ?></h2>
    </div>
</div>

<div class="row boxed">
    <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" method="post">
        <input type="hidden" name="action" value="crysli_campaign_update_recipients">
        <?php wp_nonce_field('crysli_campaign_update_recipients'); ?>
        <input type="hidden" name="campaign_unique_id" value="<?php echo esc_attr($campaign['campaignUniqueId']); ?>">

        <input type="hidden"
               name="campaign_recipients[]"
               v-for="userId in selected"
               :key="'selected-user-' + userId"
               :value="userId">

        <div class="col-12" style="position: relative">
            <div class="stina-form-group">
                <label><strong><?php _e('Condition', 'stina-crystal-lift'); ?></strong></label>

                <div class="stina-condition-group stina-list-group stina-mb-1">

                    <div class="stina-list-group-item" v-if="conditions.length === 0">
                        <p class="stina-m-0"><?php _e('Click on the "Add condition" button to filter your recipients.', 'stina-crystal-lift'); ?></p>
                    </div>

                    <div class="stina-condition stina-list-group-item stina-flexbox stina-align-items-baseline stina-w-12"
                         v-if="conditions.length > 0"
                         v-for="(condition, i) in conditions"
                         data-or="<?php esc_attr_e(strtoupper(__('and', 'stina-crystal-lift'))); ?>"
                         :key="'stina-recipients-condition-' + i">

                        <!-- CONDITION OBJECT -->
                        <div class="stina-mr-1" style="flex-basis: 16.66%">
                            <label :for="'stina-condition-object-' + i"
                                   class="sr-only">
                                <?php _e('Object', 'stina-crystal-lift'); ?>
                            </label>
                            <select :id="'stina-condition-object-' + i"
                                    class="stina-form-control stina-form-control-sm"
                                    :name="'campaign_condition[' + i + '][object]'"
                                    v-model="condition.object"
                                    @change="condition.entity = ''"
                                    required="required">
                                <option value="">-- <?php _e('Please select', 'stina-crystal-lift'); ?> --</option>
                                <option :value="object.name"
                                        v-for="(object, i) in filters"
                                        :key="'stina-recipients-condition-object-' + i">
                                    {{ object.label }}
                                </option>
                            </select>
                        </div>

                        <!-- CONDITION ENTITY -->
                        <div class="stina-mr-1" style="flex-basis: 16.66%">
                            <label :for="'stina-condition-entity-' + i"
                                   class="sr-only">
                                <?php _e('Entity', 'stina-crystal-lift'); ?>
                            </label>
                            <select :id="'stina-condition-entity-' + i"
                                    class="stina-form-control stina-form-control-sm"
                                    :name="'campaign_condition[' + i + '][entity]'"
                                    v-model="condition.entity"
                                    @change="condition.operator = ''"
                                    required="required">
                                <option value="">-- <?php _e('Please select', 'stina-crystal-lift'); ?> --</option>
                                <option :value="entity.name"
                                        v-for="(entity, j) in getObjectEntities(condition.object)"
                                        :key="'stina-recipients-condition-entity-' + j">
                                    {{ entity.label }}
                                </option>
                            </select>
                        </div>

                        <!-- CONDITION OPERATOR -->
                        <div class="stina-mr-1"
                             style="flex-basis: 16.67%"
                             v-for="(field, k) in getObjectEntityFields(condition.object, condition.entity)"
                             :key="'stina-recipients-condition-fields-' + k">
                            <label :for="'stina-condition-operator-' + i"
                                   class="sr-only">
                                <?php _e('Operator', 'stina-crystal-lift'); ?>
                            </label>
                            <select :id="'stina-condition-operator-' + i"
                                    class="stina-form-control stina-form-control-sm"
                                    :name="'campaign_condition[' + i + '][operator]'"
                                    v-model="condition.operator">
                                <option value="">-- <?php _e('Please select', 'stina-crystal-lift'); ?> --</option>
                                <option :value="operatorKey"
                                        v-for="(operatorValue, operatorKey) in field.values"
                                        :key="'stina-recipients-field-values-' + operatorKey">
                                    {{ operatorValue }}
                                </option>
                            </select>
                        </div>

                        <!-- CONDITION VALUE -->
                        <div class="stina-mr-1" style="flex-basis: 50%">
                            <label :for="'stina-condition-value-' + i"
                                   class="sr-only">
                                <?php _e('Value', 'stina-crystal-lift'); ?>
                            </label>
                            <input :id="'stina-condition-value-' + i"
                                   class="stina-form-control stina-form-control-sm"
                                   :name="'campaign_condition[' + i + '][value]'"
                                   :type="getInputFieldType(condition.object, condition.entity)"
                                   v-if="condition.object && condition.entity && !isMultiField(condition.entity)"
                                   v-model="condition.value">
                            <stina-select2 :id="'stina-condition-value-' + i"
                                           :index="i"
                                           class="stina-form-control stina-form-control-select2"
                                           selection-css-class="stina-select2-selection stina-select2-selection-sm"
                                           dropdown-css-class="stina-select2-dropdown"
                                           :name="'campaign_condition[' + i + '][value][]'"
                                           :ajax="getConditionAjaxProp(condition.entity)"
                                           :allow-clear="true"
                                           :placeholder="getConditionDropdownProp(condition.entity)"
                                           :multiple="true"
                                           :minimum-input-length="0"
                                           v-if="condition.object && condition.entity && isMultiField(condition.entity)"
                                           v-model="condition.value"
                                           style=""
                                           @input="onUpdateConditionValue"></stina-select2>
                        </div>

                        <!-- REMOVE CONDITION -->
                        <div>
                            <button type="button"
                                    class="stina-btn stina-btn-sm stina-btn-primary stina-m-0"
                                    @click="onRemoveCondition(i)">
                                <span class="sr-only"><?php _e('Remove condition', 'stina-crystal-lift'); ?></span>
                                <i class="fa fas fa-trash"></i>
                            </button>
                        </div>

                    </div>

                </div>

                <button type="button"
                        class="stina-btn stina-btn-sm stina-btn-primary"
                        @click="onFilterRecipients"
                        :disabled="onValidateConditions() === false">
                    <?php _e('Filter recipients', 'stina-crystal-lift'); ?>
                </button>

                <button type="button"
                        class="stina-btn stina-btn-sm stina-btn-secondary"
                        @click="onAddCondition"
                        v-if="conditions.length === 0">
                    <?php _e('Add condition', 'stina-crystal-lift'); ?>
                </button>
            </div>

            <div>
                <p><?php printf(__('<b>%s</b> recipients have been selected.', 'stina-crystal-lift'), '{{ selected.length }}'); ?></p>
            </div>

            <div class="stina-table-responsive stina-edit-recipients-table" style="position: relative">
                <table class="stina-table stina-mb-0" v-if="!loading">
                    <thead>
                    <tr>
                        <th class="stina-table-checkbox">
                            <input type="checkbox" @change="onSelectAll" v-model="selectAll">
                        </th>
                        <th><?php _e('Email', 'stina-crystal-lift'); ?></th>
                        <th><?php _e('First name', 'stina-crystal-lift'); ?></th>
                        <th><?php _e('Last name', 'stina-crystal-lift'); ?></th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr v-for="(user, i) in users.list" :key="i">
                        <td class="stina-table-checkbox">
                            <input type="checkbox" :value="user.id" v-model="selected">
                        </td>
                        <td><strong><a :href="'mailto:' + user.email">{{ user.email }}</a></strong></td>
                        <td>{{ user.firstName }}</td>
                        <td>{{ user.lastName }}</td>
                    </tr>
                    </tbody>
                </table>

                <?php crysli_get_template('loading.php'); ?>
            </div>

        </div>

        <div class="col-12">
            <p class="stina-mt-0" v-if="selected.length === 0">
                <?php _e('Please select at least one recipient.', 'stina-crystal-lift'); ?>
            </p>

            <button class="stina-btn stina-btn-primary"
                    type="submit"
                    name="crysli_campaign_update_users"
                    :disabled="selected.length === 0">
                <?php _e('Update', 'stina-crystal-lift'); ?>
            </button>
        </div>

    </form>
</div>