<?php

use STINA\CrystalLift\Enumerators\CampaignAction as CampaignActionEnumerator;
use STINA\CrystalLift\Enumerators\CampaignStatus as CampaignStatusEnumerator;
use STINA\CrystalLift\Enumerators\CampaignType as CampaignTypeEnumerator;
use STINA\CrystalLift\Enumerators\Page;
use STINA\CrystalLift\Models\Resources\CampaignRecipientRel as CampaignRecipientRelResourceModel;

defined('ABSPATH') || exit;

/**
 * Edit campaign main component
 *
 * @version 1.0.0
 *
 * @var false|array                               $campaign
 * @var string                                    $campaignType
 * @var string                                    $campaignStatus
 * @var string                                    $campaignAction
 * @var string                                    $campaignConfig
 * @var false|array                               $isEventConfigured
 * @var bool                                      $isTriggerDialogConfigured
 * @var false|CampaignRecipientRelResourceModel[] $recipients
 */

?>

<script type="text/javascript">
  function crysliOpenModal(id) {
    var modal = document.querySelector('#' + id);

    if (modal) {
      modal.classList.add('open');
    }
  }
</script>

<div class="wrap stina-wrap">

    <div class="stina-row">
        <div class="col-12">
            <?php stina_alerts(); ?>
        </div>
    </div>

    <div class="stina-row">
        <div class="col-12">
            <div class="stina-header">
                <a class="stina-link stina-d-ib stina-mr-1" href="<?php echo esc_url(admin_url('admin.php?page=' . Page::CAMPAIGNS)); ?>">
                    <span class="sr-only"><?php _e('Back', 'stina-crystal-lift'); ?></span>
                    <i class="fas fa-arrow-left fa-1x" aria-hidden="true"></i>
                </a>
                <h1 class="stina-header-title stina-d-ib">
                    <?php echo esc_html($campaign['campaignDescLong']); ?>
                </h1>
            </div>
        </div>
    </div>

    <div class="stina-row">
        <div class="col-12">

            <!-- EDIT CAMPAIGN CARD -->
            <div class="stina-card stina-mb-1">

                <div class="stina-card-header">
                    <h2 class="stina-m-0"><?php _e('Configuration', 'stina-crystal-lift'); ?></h2>
                </div>

                <!-- RECIPIENTS -->
                <?php if ($campaignType === CampaignTypeEnumerator::CAMPAIGN_REGULAR): ?>

                    <div class="stina-card-body stina-border-bottom stina-flexbox stina-edit-campaign-section">

                        <div class="stina-edit-campaign-section-checkmark">
                            <?php if ($recipients !== false && !empty($recipients)): ?>
                                <i class="fas fa-check-circle fa-3x" style="color: #1B998B;"></i>
                            <?php else: ?>
                                <i class="fas fa-exclamation-circle fa-3x" style="color: #FF9F1C;"></i>
                            <?php endif; ?>
                        </div>

                        <div class="stina-edit-campaign-section-info">
                            <h3 class="stina-mt-0"><?php echo _x('Recipients', 'List of recipients. i.e. "To all subscribed contacts"', 'stina-crystal-lift'); ?></h3>

                            <p class="stina-mb-0">
                                <?php

                                if (!empty($recipients)) {
                                    printf(
                                        __('<b>%d</b> recipients selected.', 'stina-crystal-lift'),
                                        count($recipients)
                                    );
                                } else {
                                    _e('Please add recipients to your campaign.', 'stina-crystal-lift');
                                }

                                ?>
                            </p>

                        </div>

                        <div class="stina-edit-campaign-section-actions">
                            <button id="crysli-campaign-content-edit"
                                    class="stina-btn stina-btn-primary stina-m-0"
                                    onclick="crysliOpenModal('crysli-modal-campaign-edit-recipients-wizard')">
                                <?php _e('Edit recipients', 'stina-crystal-lift'); ?>
                            </button>
                        </div>

                    </div>

                <?php endif; ?>

                <!-- EVENT -->
                <?php if ($campaignType === CampaignTypeEnumerator::CAMPAIGN_AUTOMATED_EVENT_BASED): ?>

                    <div class="stina-card-body stina-border-bottom stina-flexbox stina-edit-campaign-section">

                        <div class="stina-edit-campaign-section-checkmark">
                            <?php if ($isEventConfigured): ?>
                                <i class="fas fa-check-circle fa-3x" style="color: #1B998B;"></i>
                            <?php else: ?>
                                <i class="fas fa-exclamation-circle fa-3x" style="color: #FF9F1C;"></i>
                            <?php endif; ?>
                        </div>

                        <div class="stina-edit-campaign-section-info">
                            <h3 class="stina-mt-0"><?php _e('Event', 'stina-crystal-lift'); ?></h3>
                            <p class="stina-mb-0"><?php _e('Here you can configure the event object, trigger, and conditions.', 'stina-crystal-lift'); ?></p>
                        </div>

                        <div class="stina-edit-campaign-section-actions">
                            <button id="crysli-campaign-content-edit"
                                    class="stina-btn stina-btn-primary stina-m-0"
                                    onclick="crysliOpenModal('crysli-modal-campaign-configure-event-wizard')">
                                <?php _e('Configure campaign event', 'stina-crystal-lift'); ?>
                            </button>
                        </div>

                    </div>

                <?php endif; ?>

                <!-- CONTENT -->
                <?php if ($campaignAction === CampaignActionEnumerator::TRIGGER_DIALOG_LETTER): ?>

                    <div class="stina-card-body stina-border-bottom stina-flexbox stina-edit-campaign-section">

                        <div class="stina-edit-campaign-section-checkmark">
                            <?php if ($campaignConfig): ?>
                                <i class="fas fa-check-circle fa-3x" style="color: #1B998B;"></i>
                            <?php else: ?>
                                <i class="fas fa-exclamation-circle fa-3x" style="color: #FF9F1C;"></i>
                            <?php endif; ?>
                        </div>

                        <div class="stina-edit-campaign-section-info">
                            <h3 class="stina-mt-0"><?php _e('Trigger Dialog Campaign', 'stina-crystal-lift'); ?></h3>
                            <p class="stina-mb-0"><?php _e('Configure the Trigger Dialog campaign by defining its name and variable mapping.', 'stina-crystal-lift'); ?></p>
                        </div>

                        <div class="stina-edit-campaign-section-actions">
                            <button id="crysli-campaign-content-edit"
                                    class="stina-btn stina-btn-primary stina-m-0"
                                    onclick="crysliOpenModal('crysli-modal-campaign-edit-content-wizard')">

                                <?php if (!$campaignConfig): ?>

                                    <?php _e('Add content', 'stina-crystal-lift'); ?>

                                <?php else: ?>

                                    <?php _e('Update content', 'stina-crystal-lift'); ?>

                                <?php endif; ?>

                            </button>
                        </div>

                    </div>

                <?php endif; ?>

                <!-- CONFIRM TRIGGER DIALOG -->
                <?php if ($campaignAction === CampaignActionEnumerator::TRIGGER_DIALOG_LETTER): ?>

                    <div class="stina-card-body stina-flexbox stina-edit-campaign-section">

                        <div class="stina-edit-campaign-section-checkmark">
                            <?php if ($isTriggerDialogConfigured): ?>
                                <i class="fas fa-check-circle fa-3x" style="color: #1B998B;"></i>
                            <?php else: ?>
                                <i class="fas fa-exclamation-circle fa-3x" style="color: #FF9F1C;"></i>
                            <?php endif; ?>
                        </div>


                        <div class="stina-edit-campaign-section-info">
                            <h3 class="stina-mt-0"><?php _e('Trigger Dialog Configuration', 'stina-crystal-lift'); ?></h3>


                            <p class="stina-mb-0">
                                <?php printf(
                                    __('Please also make sure that you have configured your campaign inside the <b><a href="%s" target="_blank" rel="noopener noreferrer">Deutsche Post Trigger Dialog dashboard <i class="fas fa-external-link-square-alt"></i></a></b> before sending out / activating the campaign.', 'stina-crystal-lift'),
                                    esc_url($campaign['triggerDialogUrl'])
                                ); ?>
                            </p>

                            <?php if (!$isTriggerDialogConfigured): ?>

                                <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" class="stina-mt-1" method="post">
                                    <input type="hidden" name="action" value="crysli_campaign_update_trigger_dialog_confirmation">
                                    <?php wp_nonce_field('crysli_campaign_update_trigger_dialog_confirmation'); ?>
                                    <input type="hidden" name="campaign_unique_id" value="<?php echo esc_attr($campaign['campaignUniqueId']); ?>">

                                    <button class="stina-btn stina-btn-primary" type="submit">
                                        <?php _e('I confirm, that the campaign is configured', 'stina-crystal-lift'); ?>
                                    </button>
                                </form>

                            <?php else: ?>

                            <?php endif; ?>

                        </div>

                    </div>

                <?php endif; ?>


                <!-- FOOTER -->

                <?php if ($campaignStatus !== CampaignStatusEnumerator::CAMPAIGN_SUBMITTED): ?>

                    <div class="stina-card-footer">

                        <?php if ($campaignType === CampaignTypeEnumerator::CAMPAIGN_AUTOMATED_EVENT_BASED): ?>

                            <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" method="post">
                                <input type="hidden" name="action" value="crysli_campaign_update_status">
                                <?php wp_nonce_field('crysli_campaign_update_status'); ?>
                                <input type="hidden" name="campaign_name" value="<?php echo esc_attr($campaign['campaignDescLong']); ?>">
                                <input type="hidden" name="campaign_type" value="<?php echo esc_attr($campaignType); ?>">
                                <input type="hidden" name="campaign_unique_id" value="<?php echo esc_attr($campaign['campaignUniqueId']); ?>">
                                <input type="hidden" name="campaign_event_unique_id" value="<?php echo esc_attr($campaign['events'][0]['eventUniqueId']); ?>">
                                <input type="hidden" name="campaign_action_unique_id" value="<?php echo esc_attr($campaign['actions'][0]['actionUniqueId']); ?>">

                                <?php if ($campaignStatus === CampaignStatusEnumerator::CAMPAIGN_DRAFT || $campaignStatus === CampaignStatusEnumerator::CAMPAIGN_INACTIVE): ?>

                                    <?php
                                    $disabled = 'disabled="disabled"';

                                    if ($campaignConfig && $isEventConfigured && $isTriggerDialogConfigured) {
                                        $disabled = '';
                                    }
                                    ?>

                                    <input type="hidden" name="campaign_status" value="<?php echo esc_attr(CampaignStatusEnumerator::CAMPAIGN_ACTIVE); ?>">
                                    <button class="stina-btn stina-btn-primary" type="submit" <?php echo $disabled; ?>>
                                        <?php _e('Activate campaign', 'stina-crystal-lift'); ?>
                                    </button>

                                <?php endif; ?>

                                <?php if ($campaignStatus === CampaignStatusEnumerator::CAMPAIGN_ACTIVE): ?>

                                    <input type="hidden" name="campaign_status" value="<?php echo esc_attr(CampaignStatusEnumerator::CAMPAIGN_INACTIVE); ?>">
                                    <button class="stina-btn stina-btn-primary" type="submit"><?php _e('Deactivate campaign', 'stina-crystal-lift'); ?></button>

                                <?php endif; ?>

                            </form>

                        <?php endif; ?>

                        <!-- ACTIVATE/DEACTIVATE CAMPAIGN -->
                        <?php if ($campaignType === CampaignTypeEnumerator::CAMPAIGN_REGULAR && $campaignStatus === CampaignStatusEnumerator::CAMPAIGN_INACTIVE): ?>

                            <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" method="post">
                                <input type="hidden" name="action" value="crysli_campaign_update_status">
                                <?php wp_nonce_field('crysli_campaign_update_status'); ?>
                                <input type="hidden" name="campaign_name" value="<?php echo esc_attr($campaign['campaignDescLong']); ?>">
                                <input type="hidden" name="campaign_type" value="<?php echo esc_attr($campaignType); ?>">
                                <input type="hidden" name="campaign_unique_id" value="<?php echo esc_attr($campaign['campaignUniqueId']); ?>">
                                <input type="hidden" name="campaign_event_unique_id" value="<?php echo esc_attr($campaign['events'][0]['eventUniqueId']); ?>">
                                <input type="hidden" name="campaign_action_unique_id" value="<?php echo esc_attr($campaign['actions'][0]['actionUniqueId']); ?>">

                                <?php if ($campaignStatus === CampaignStatusEnumerator::CAMPAIGN_DRAFT || $campaignStatus === CampaignStatusEnumerator::CAMPAIGN_INACTIVE): ?>

                                    <input type="hidden" name="campaign_status" value="<?php echo esc_attr(CampaignStatusEnumerator::CAMPAIGN_ACTIVE); ?>">
                                    <button class="stina-btn stina-btn-primary" type="submit"><?php _e('Activate campaign', 'stina-crystal-lift'); ?></button>

                                <?php endif; ?>

                                <?php if ($campaignStatus === CampaignStatusEnumerator::CAMPAIGN_ACTIVE): ?>

                                    <input type="hidden" name="campaign_status" value="<?php echo esc_attr(CampaignStatusEnumerator::CAMPAIGN_INACTIVE); ?>">
                                    <button class="stina-btn stina-btn-primary" type="submit"><?php _e('Deactivate campaign', 'stina-crystal-lift'); ?></button>

                                <?php endif; ?>

                            </form>

                        <?php endif; ?>

                        <!-- SEND CAMPAIGN -->
                        <?php if ($campaignType === CampaignTypeEnumerator::CAMPAIGN_REGULAR && $campaignStatus === CampaignStatusEnumerator::CAMPAIGN_ACTIVE): ?>

                            <?php
                            $disabled = 'disabled="disabled"';

                            if (!empty($recipients) && $campaignConfig && $isTriggerDialogConfigured) {
                                $disabled = '';
                            }
                            ?>

                            <form action="<?php echo esc_url(admin_url('admin-post.php')); ?>" method="post">
                                <input type="hidden" name="action" value="crysli_campaign_send_campaign">
                                <?php wp_nonce_field('crysli_campaign_send_campaign'); ?>
                                <input type="hidden" name="campaign_unique_id" value="<?php echo esc_attr($campaign['campaignUniqueId']); ?>">

                                <button class="stina-btn stina-btn-primary" type="submit" <?php echo $disabled; ?>>
                                    <?php _e('Send', 'stina-crystal-lift'); ?>
                                </button>

                            </form>

                        <?php endif; ?>

                    </div>

                <?php endif; ?>
            </div>

        </div>

    </div>

</div>
