<?php

use STINA\CrystalLift\Enumerators\CampaignStatus as CampaignStatusEnumerator;
use STINA\CrystalLift\Enumerators\Page as PageEnumerator;
use STINA\Library\Interfaces\UiComponent as UiComponentInterface;

defined('ABSPATH') || exit;

/**
 * Campaign main component
 *
 * @version 1.0.0
 * @var UiComponentInterface[] $ui
 */

?>

<script type="text/javascript">
  function crysliOpenCampaignModal() {
    var modal = document.querySelector('#crysli-modal-campaign-create-wizard');

    if (modal) {
      modal.classList.add('open');
    }
  }

  function crysliOpenDuplicateCampaignDialog() {
    var dialog = document.querySelector('#crysli-dialog-campaign-duplicate');

    if (dialog) {
      dialog.classList.add('open');
    }
  }
</script>

<div id="stina-campaigns" class="wrap stina-wrap">

    <div class="stina-row">
        <div class="col-12">
            <?php stina_alerts(); ?>
        </div>
    </div>

    <div class="stina-row">
        <div class="col-12">
            <div class="stina-header">
                <?php $ui['heading']->render(); ?>
            </div>
        </div>
    </div>

    <div class="stina-row">
        <div class="col-12">
            <div class="stina-card">
                <div class="stina-card-body">
                    <h2><?php _e('Manage all your campaigns', 'stina-crystal-lift'); ?></h2>
                    <p><?php _e('Complete an existing campaign, or create a completely new marketing campaign to engage your audience!', 'stina-crystal-lift'); ?></p>
                    <button class="stina-btn stina-btn-lg stina-btn-primary stina-m-0" onclick="crysliOpenCampaignModal()">
                        <i class="fas fa-bullhorn" style="margin-right: .25em"></i>
                        <?php _e('Create campaign', 'stina-crystal-lift'); ?>
                    </button>
                </div>
            </div>
        </div>
    </div>

    <div class="stina-row">
        <div class="col-12">

            <div class="stina-component-sidebar">
                <div class="stina-card">
                    <div class="stina-card-body">
                        <div class="stina-component-sidebar-status-filters">
                            <h4 class="stina-component-sidebar-heading">
                                <?php _e('View by Status', 'stina-crystal-lift'); ?>
                            </h4>

                            <ul class="stina-component-sidebar-nav">
                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('status', 'ALL')"
                                            :class="{ active: campaigns.selected.status === null }">
                                        <?php _e('All', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>
                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('status', 'CAMPAIGN_DRAFT')"
                                            :class="{ active: campaigns.selected.status === 'CAMPAIGN_DRAFT' }">
                                        <?php _e('Draft', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>
                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('status', 'CAMPAIGN_ACTIVE')"
                                            :class="{ active: campaigns.selected.status === 'CAMPAIGN_ACTIVE' }">
                                        <?php _e('Active', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>
                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('status', 'CAMPAIGN_INACTIVE')"
                                            :class="{ active: campaigns.selected.status === 'CAMPAIGN_INACTIVE' }">
                                        <?php _e('Inactive', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>

                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('status', 'CAMPAIGN_SUBMITTED')"
                                            :class="{ active: campaigns.selected.status === 'CAMPAIGN_SUBMITTED' }">
                                        <?php _e('Submitted', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>
                            </ul>
                        </div>

                        <div class="stina-component-sidebar-separator"></div>

                        <div class="stina-component-sidebar-type-filters">
                            <h4 class="stina-component-sidebar-heading"><?php _e('View by Type', 'stina-crystal-lift'); ?></h4>

                            <ul class="stina-component-sidebar-nav">
                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('type', 'ALL')"
                                            :class="{ active: campaigns.selected.type === null }">
                                        <?php _e('All', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>
                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('type', 'CAMPAIGN_REGULAR')"
                                            :class="{ active: campaigns.selected.type === 'CAMPAIGN_REGULAR' }">
                                        <?php _e('Regular', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>
                                <li>
                                    <button class="stina-link"
                                            @click="onSelectFilter('type', 'CAMPAIGN_AUTOMATED_EVENT_BASED')"
                                            :class="{ active: campaigns.selected.type === 'CAMPAIGN_AUTOMATED_EVENT_BASED' }">
                                        <?php _e('Automated (Event-Based)', 'stina-crystal-lift'); ?>
                                    </button>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

            <div class="stina-component-main"  style="position: relative;">

                <div class="stina-mb-1">
                    <label class="sr-only" for="crysli_search_campaigns">
                        <?php _e('Find a campaign by name', 'stina-crystal-lift'); ?>
                    </label>
                    <form @submit.prevent="onRefresh">

                        <input id="crysli_search_campaigns"
                               type="text"
                               class="stina-form-control stina-w-12"
                               placeholder="<?php esc_attr_e('Find a campaign by name', 'stina-crystal-lift'); ?>"
                               v-model="campaigns.term">
                    </form>
                </div>

                <div class="stina-mb-1">
                    <stina-pagination :page="campaigns.page"
                                      :limit="campaigns.limit"
                                      :total="campaigns.total"
                                      @paginate="onChangePage"></stina-pagination>
                </div>

                <ul class="stina-list-group" v-if="campaigns.list.length > 0" v-cloak>
                    <li class="stina-list-group-item campaign-list-item stina-flexbox"
                        v-for="campaign of campaigns.list"
                        :key="campaign.campaignUniqueId">
                        <div class="campaign-list-item-icon-container">
                            <i class="campaign-list-item-icon fa-2x"
                               :class="getCampaignProviderIcon(campaign.actions[0].actionDescShort)"></i>
                        </div>

                        <div class="campaign-list-item-details">
                            <a class="campaign-list-item-details-heading"
                               v-if="campaign.campaignStatus !== 'CAMPAIGN_SUBMITTED'"
                               :title="campaign.campaignDescLong"
                               :href="'<?php echo esc_url("admin.php?page=" . PageEnumerator::CAMPAIGNS . "&id="); ?>' + campaign.campaignUniqueId">
                                {{ campaign.campaignDescLong }}
                            </a>

                            <a class="campaign-list-item-details-heading"
                               v-if="campaign.campaignStatus === 'CAMPAIGN_SUBMITTED'"
                               :href="'<?php echo esc_url("admin.php?page=" . PageEnumerator::CAMPAIGNS . "&id="); ?>' + campaign.campaignUniqueId + '&action=view-report'"
                               :title="campaign.campaignDescLong">
                                {{ campaign.campaignDescLong }}
                            </a>

                            <small>{{ i18n.LABELS.campaign.action[campaign.actions[0].actionDescShort] }}</small>
                            <strong aria-hidden="true">&middot;</strong>
                            <small>{{ i18n.LABELS.campaign.provider[campaign.actions[0].provider.providerDescShort] }}</small>
                            <strong aria-hidden="true">&middot;</strong>
                            <small>{{ i18n.LABELS.campaign.type[campaign.campaignType] }}</small>
                            <br>
                            <div class="stina-mt-1 stina-text-small" v-if="campaign.metaInsertDt">
                                <small>
                                    <?php printf(
                                        __('Created <strong>%s</strong> by %s', 'stina-crystal-lift'),
                                        '{{ moment(campaign.metaInsertDt).format(\'DD.MM.YYYY\') }}',
                                        _x('you', 'The person who created this entity', 'stina-crystal-lift')
                                    );
                                    ?>
                                </small>
                            </div>
                            <div class="stina-mt-1 stina-text-small" v-else-if="campaign.metaUpdateDt">
                                <small>
                                    <?php printf(
                                        __('Updated <strong>%s</strong> by %s', 'stina-crystal-lift'),
                                        '{{ moment(campaign.metaUpdateDt).format(\'DD.MM.YYYY\') }}',
                                        _x('you', 'The person who last updated this entity', 'stina-crystal-lift')
                                    );
                                    ?>
                                </small>
                            </div>
                        </div>
                        <div class="campaign-list-item-status">
                                <span class="stina-badge stina-d-ib stina-text-center"
                                      :class="getCampaignStatusClass(campaign.campaignStatus)">
                                    {{ i18n.LABELS.campaign.status[campaign.campaignStatus] }}
                                </span>
                        </div>
                        <div class="campaign-list-item-actions">

                            <a class="stina-btn stina-btn-primary"
                               v-if="campaign.campaignStatus === 'CAMPAIGN_ACTIVE' || campaign.campaignStatus === 'CAMPAIGN_DRAFT'"
                               :href="'<?php echo esc_url("admin.php?page=" . PageEnumerator::CAMPAIGNS . "&id="); ?>' + campaign.campaignUniqueId">
                                <?php _e('Edit', 'stina-crystal-lift'); ?>
                            </a>

                            <a class="stina-btn stina-btn-primary"
                               v-if="campaign.campaignStatus === 'CAMPAIGN_SUBMITTED' || campaign.campaignType === 'CAMPAIGN_AUTOMATED_EVENT_BASED'"
                               :href="'<?php echo esc_url("admin.php?page=" . PageEnumerator::CAMPAIGNS . "&id="); ?>' + campaign.campaignUniqueId + '&action=view-report'">
                                <?php _e('View report', 'stina-crystal-lift'); ?>
                            </a>

                            <button class="stina-btn stina-btn-primary"
                                    type="button"
                                    onclick="crysliOpenDuplicateCampaignDialog()"
                                    @click="onOpenDuplicateCampaignDialog(campaign.campaignUniqueId)"
                                    v-if="campaign.campaignStatus === 'CAMPAIGN_SUBMITTED'">
                                <?php _e('Duplicate', 'stina-crystal-lift'); ?>
                            </button>

                        </div>
                    </li>
                </ul>

                <div class="stina-border stina-p-1 stina-pt-2 stina-flexbox"
                     style="background-color: #FFFFFF; flex-direction: column; border-radius: .25rem; align-items: center; position: relative;"
                     v-cloak
                     v-if="campaigns.list.length === 0 && loading === false">
                    <i class="fas fa-exclamation-triangle fa-3x"></i>
                    <h2 class="stina-text-center"><?php _e('No campaigns found', 'stina-crystal-lift'); ?></h2>
                </div>

                <?php crysli_get_template('loading.php'); ?>

            </div>

        </div>
    </div>

</div>
