<?php

use STINA\CrystalLift\Enumerators\CampaignType;
use STINA\CrystalLift\Enumerators\Page;

defined('ABSPATH') || exit;

/**
 * View campaign report component
 *
 * @version 1.1.0
 *
 * @var array       $campaign
 * @var false|array $triggers
 */

?>

<div class="wrap stina-wrap">

    <div class="stina-row">
        <div class="col-12">
            <?php stina_alerts(); ?>
        </div>
    </div>

    <div class="stina-row">
        <div class="col-12">
            <div class="stina-header">
                <a class="stina-link stina-d-ib stina-mr-1" href="<?php echo esc_url(admin_url('admin.php?page=' . Page::CAMPAIGNS)); ?>">
                    <span class="sr-only"><?php _e('Back', 'stina-crystal-lift'); ?></span>
                    <i class="fas fa-arrow-left fa-1x" aria-hidden="true"></i>
                </a>
                <h1 class="stina-header-title stina-d-ib">
                    <?php echo esc_html($campaign['campaignDescLong']); ?>
                </h1>
            </div>
        </div>
    </div>

    <div class="stina-row">
        <div class="col-12">
            <div class="stina-card stina-border-none">
                <div class="stina-card-header stina-border-top stina-border-left stina-border-right" style="border-bottom: none;">
                    <h2 class="stina-m-0">
                        <?php _e('Recipients', 'stina-crystal-lift'); ?>
                        <span class="stina-text-small stina-badge primary"><?php echo esc_html($triggers['total']); ?></span>
                    </h2>
                </div>
                <div class="stina-card-body stina-p-0">
                    <div class="stina-table-responsive">
                        <table class="stina-table stina-m-0">
                            <thead>
                            <th><strong><?php _e('Submission Date', 'stina-crystal-lift'); ?></strong></th>
                            <th><strong><?php _e('Status', 'stina-crystal-lift'); ?></strong></th>
                            <th><strong><?php _e('Campaign', 'stina-crystal-lift'); ?></strong></th>
                            <th><strong><?php _e('Variables', 'stina-crystal-lift'); ?></strong></th>
                            </thead>
                            <tbody>

                            <?php if (!$triggers || $triggers['total'] === 0): ?>

                                <td colspan="4" class="stina-text-center" style="vertical-align: inherit">
                                    <div class="stina-p-1 stina-flexbox" style="flex-direction: column">
                                        <i class="fas fa-exclamation-triangle fa-3x" style="margin: 0 auto;"></i>
                                        <h2 class="stina-text-center stina-mb-0">
                                            <?php _e('No recipients found.', 'stina-crystal-lift'); ?>
                                        </h2>
                                    </div>
                                </td>

                            <?php else: ?>

                                <?php foreach (array_reverse($triggers['list'], true) as $i => $triggerRow): ?>
                                    <?php $triggerResults = $triggerRow['payload']['triggerResults']; ?>
                                    <?php $triggerHeader = $triggerRow['header']; ?>

                                    <?php if (isset($triggerRow['payload']['actionData']['campaignVariables'])): ?>

                                        <?php foreach($triggerRow['payload']['actionData']['campaignVariables'] as $j => $campaignVariable): ?>

                                            <tr>
                                                <td>
                                                    <?php crysli_get_timestamp_from_utc($triggerHeader['timestampDateTime'], true); ?>
                                                </td>
                                                <td>
                                                    <?php if ($triggerResults[$j]['status'] === 'SUCCESS'): ?>

                                                        <span class="stina-badge success">
                                                        <?php _e('Submitted', 'stina-crystal-lift') ;?>
                                                    </span>

                                                    <?php else: ?>

                                                        <span class="stina-badge danger">
                                                        <?php _e('Failed', 'stina-crystal-lift') ;?>
                                                    </span>

                                                    <?php endif; ?>
                                                </td>
                                                <td>
                                                    <ul class="stina-text-small stina-m-0">
                                                        <li>
                                                            <strong><?php _e('Name', 'stina-crystal-lift'); ?>:</strong>
                                                            <span><?php echo esc_html($campaign['campaignDescLong']); ?></span>
                                                        </li>
                                                        <li>
                                                            <strong><?php _e('Type', 'stina-crystal-lift'); ?>:</strong>
                                                            <span><?php echo CampaignType::label($campaign['campaignType']); ?></span>
                                                        </li>
                                                        <li>
                                                            <strong><?php _e('Provider', 'stina-crystal-lift'); ?>:</strong>
                                                            <span><?php echo esc_html($campaign['actions'][0]['provider']['providerDescLong']); ?></span>
                                                        </li>
                                                        <li>
                                                            <strong><?php _e('Channel', 'stina-crystal-lift'); ?>:</strong>
                                                            <span><?php echo esc_html($campaign['actions'][0]['actionDescLong']); ?></span>
                                                        </li>
                                                        <li>
                                                            <strong><?php _e('Media format', 'stina-crystal-lift'); ?>:</strong>
                                                            <span><?php _e('Offline Print Marketing', 'stina-crystal-lift'); ?></span>
                                                        </li>
                                                        <li>
                                                            <strong><?php _e('Last modified', 'stina-crystal-lift'); ?>:</strong>

                                                            <?php if ($campaign['metaUpdateDt']): ?>

                                                                <?php crysli_get_timestamp_from_utc($campaign['metaUpdateDt'], true) ;?>

                                                            <?php else: ?>

                                                                <?php crysli_get_timestamp_from_utc($campaign['metaInsertDt'], true) ;?>

                                                            <?php endif; ?>
                                                        </li>
                                                        <li>
                                                            <strong>ID:</strong>
                                                            <code><?php echo esc_html($campaign['campaignUniqueId']); ?></code>
                                                        </li>
                                                    </ul>
                                                </td>
                                                <td>
                                                    <ul class="stina-text-small stina-m-0">

                                                        <?php if (isset($triggerRow['payload']['actionData'])): ?>

                                                            <?php foreach (array_reverse($campaignVariable) as $name => $value): ?>

                                                                <?php if ($name === 'triggerUniqueId'): ?>

                                                                    <li>
                                                                        <strong>ID:</strong>
                                                                        <code><?php echo esc_html($value); ?></code>
                                                                    </li>

                                                                <?php else: ?>

                                                                    <li>
                                                                        <strong><?php echo esc_html($name); ?>:</strong>
                                                                        <span><?php echo esc_html($value); ?></span>
                                                                    </li>

                                                                <?php endif; ?>

                                                            <?php endforeach; ?>

                                                        <?php endif; ?>

                                                    </ul>
                                                </td>
                                            </tr>

                                        <?php endforeach; ?>

                                    <?php endif; ?>

                                <?php endforeach; ?>

                            <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

</div>
